SystemOrganization addCategory: #'XML-Testing'!

TestCase subclass: #XMLParserTests
	instanceVariableNames: 'testsToSkip'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-Testing'!

!XMLParserTests commentStamp: '<historical>' prior: 0!
'Class Author: Roger Whitney whitney@cs.sdsu.edu
Version 2.0
April 22, 2000

XMLParserTests uses XML tests by James Clark, Sun, and OASIS. These tests are distributed as test suite by OASIS at: 
http://www.oasis-open.org/committees/xmltest/xmlconf-19990712.zip This link can be found on the page:
http://www.oasis-open.org/committees/xmltest/testsuite.htm. 

To run the test suite you must:
	Install the OASIS test suite on your hard drive
	Edit the class method baseTestDirectory to include the full path of the directory containing the OASIS test suite.
	install Sunit.
	Run the tests the standard way: TestRunner open

The VWXMPParser does not pass all tests.  OX''s release 1.2 of Cincom''s XML parser fails about 40 tests out of about 800. This classs is configured to allow you to turn some of the tests off. The class method allTestsToSkip returns an OrderedCollection of tests that can be skiped. The tests are identified using the test ID given in the files oasis/oasis.xml, xmltest/xmltest.xml, sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml which located in the OASIS test suite. The class method skipKnownBadTests determines if the tests are skipped. The class method shouldConvertCR: determines if a test should convert the cr in the Cincom''s parsers output to lf. 

The test methods in this class are generated by class methods from files in the OASIS test suite which catalog the tests (oasis/oasis.xml, xmltest/xmltest.xml, sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml) If you wish to generate the test methods, you must edit the files sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml. They need a top-level tag to enclose the entire file. It does not matter what the tag is.

Reasons the Parser fails tests

carriage return(cr) vs line feed(lf)
	The XML spec requires all carriage returns and cr-lf pairs to be converted to lf. 
	Smalltalk strings use cr, as does the parser.

Unicode characters 
	The parser fails all/nearly all test with unicode characters. The problem is in the tests. The tests
	are not reading the answer files using UFT-8 format.

Accepts attributes with out space between them

Unicode characters with large numerical value throws an exception when stored in a stream in parser

Parser does not check for incomplete uri's
Parser does not include NOTATION elements in its tree structure
Parser does not check for valid language identification
Parser does not check for validity constraints to make a document standalone
Parser does not check name of the top level element
Parser does not check for encoding declaration in Text declarations
!

!XMLParserTests class methodsFor: 'test generation' stamp: ''!
addMethod: testMethodString classified: classificationString 

	self compile: testMethodString classified: classificationString! !

!XMLParserTests class methodsFor: 'test configuration' stamp: 'mir 1/7/2002 15:50'!
baseTestDirectory
	^ FileDirectory default directoryNamed: 'xmlconf'! !

!XMLParserTests class methodsFor: 'test generation' stamp: 'mir 1/7/2002 15:51'!
filenameAt: partialPath 
	| platformPartialPath |
	platformPartialPath _ partialPath replaceAll: $/ with: FileDirectory pathNameDelimiter.
	^ CrLfFileStream
		readOnlyFileNamed: (self baseTestDirectory directoryNamed: platformPartialPath) pathName! !

!XMLParserTests class methodsFor: 'test generation' stamp: ''!
generateTestFrom: anVWXMLElement category: aString
	|type testName testFile reference description testCode answerFile arguments |

	type := anVWXMLElement valueOfAttribute: 'TYPE' ifAbsent: [self error: 'missing test information'].
	testName := anVWXMLElement valueOfAttribute: 'ID' ifAbsent: [self error: 'missing test information'].
	testFile := anVWXMLElement valueOfAttribute: 'URI' ifAbsent: [self error: 'missing test information'].
	reference := anVWXMLElement valueOfAttribute: 'SECTIONS' ifAbsent: [self error: 'missing test information'].
	answerFile := anVWXMLElement valueOfAttribute: 'OUTPUT' ifAbsent: [nil].
	"Some test do not give correct answer. skip"
	type = 'valid' & (answerFile isNil)
		ifTrue:[^self]. 
	description := anVWXMLElement characterData.

	"sun test files do not follow the same pattern as the others"
	aString = 'sun' ifTrue:
		[testFile := 'sun/' , testFile.
		 answerFile notNil ifTrue:[ answerFile := 'sun/' , answerFile.]].

	arguments := OrderedCollection new: 5.
	arguments
		add: aString ,  (self remove: $- from: testName );
		add: testName;
		add: (description replaceAll: $" with: $ );
		add: (reference replaceAll: $" with: $ );
		add: testFile;
		add: answerFile.
	testCode := (type = 'valid') 
					ifTrue:[self validTestTemplate]
					ifFalse:[ (type = 'not-wf')
						ifTrue:[self notWellFormedTestTemplate]
						ifFalse:[ (type = 'invalid' or:[type = 'error'])
							ifTrue:[self invalidTestTemplate]
							ifFalse:[self error: 'Invalid test type']]].
	testCode := testCode expandMacrosWithArguments: arguments.
	self addMethod: testCode classified: aString , ' ' , (type replaceAll: $- with: $ ).! !

!XMLParserTests class methodsFor: 'test generation' stamp: ''!
generateTests
	"XMLParserTests generateTests"

	self
		removeTests: 'test_*';
		generateTestsFrom: 'xmltest/xmltest.xml' category:  'clark';
		generateTestsFrom: 'oasis/oasis.xml' category:  'oasis'.

	#('sun/valid/sun-valid.xml' 'sun/invalid/sun-invalid.xml' 'sun/not-wf/sun-not-wf.xml' 'sun/error/sun-error.xml') do: 
			[:each |  self generateTestsFrom: each category: 'sun']! !

!XMLParserTests class methodsFor: 'test generation' stamp: ''!
generateTestsFrom: xmlFile category: aString
	| tests  |

	tests := self xmlTestDriverIn: xmlFile .
	tests do: [:element | self generateTestFrom: element category: aString.]! !

!XMLParserTests class methodsFor: 'test configuration' stamp: ''!
haveParserValidate
	"Return true if you want the parser to validate the test XML files against the DTD
	 It is not very useful to return false, as many tests will then fail. Should remove this
	option"
	^true! !

!XMLParserTests class methodsFor: 'test templates' stamp: ''!
invalidTestTemplate
	"<1s> = test name
	 <2s> = test ID
	 <3s> = description
	 <4s> = XML spec reference
	 <5s> = test path"
	^'test<1s>
	"<3s>
	 See XML Spec. 1.0 section: <4s>"

	(self class shouldSkipTests and: [testsToSkip includes: ''<2s>''])
		ifTrue:[^nil].

	self assert: [self runTest: ''<5s>'']
		raises: self exceptionSet'! !

!XMLParserTests class methodsFor: 'test templates' stamp: ''!
notWellFormedTestTemplate
	"<1s> = test name
	 <2s> = test ID
	 <3s> = description
	 <4s> = XML spec reference
	 <5s> = test path"
	^'test<1s>
	"<3s>
	 See XML Spec. 1.0 section: <4s>"

	(self class shouldSkipTests and: [testsToSkip includes: ''<2s>''])
		ifTrue:[^nil].

	self assert: [self runTest: ''<5s>'' ]
		raises: self exceptionsTest2'! !

!XMLParserTests class methodsFor: 'test generation' stamp: ''!
remove: aCharacter from: aString
	^aString reject: [:each | each = aCharacter]! !

!XMLParserTests class methodsFor: 'test generation' stamp: ''!
removeTests: testMatchPattern 
	self selectors 
		do: [:selector | (testMatchPattern match: selector) ifTrue: [self removeSelector: selector]]! !

!XMLParserTests class methodsFor: 'test configuration' stamp: ''!
shouldConvertCR: testID
	"The XML spec requires the parser to replace cr with lf. The CINCOM parser returns cr, 
	 which is good for Smalltalk programs. Returning true with an given test ID will cause the
	test to convert cr to lf in the parsers output. There are a few instances where XML spec requires
	the parser to return a cr, so conversion is not done all the time."

	^#( "Clarks tests"
		'valid-ext-sa-001' 'valid-ext-sa-004' 'valid-ext-sa-006' 'valid-ext-sa-009' 'valid-ext-sa-011' 'valid-not-sa-031' 
	     'valid-sa-044' 'valid-sa-047' 'valid-sa-059' 'valid-sa-092'   'valid-sa-116'
		"Suns tests"
		'ext02' 'ext01' 'sa01' 'v-pe01' 'empty' 'optional' 'element')  includes: testID! !

!XMLParserTests class methodsFor: 'test configuration' stamp: ''!
shouldSkipTests
	"indicates if one wants to skip some tests"

	^true! !

!XMLParserTests class methodsFor: 'test templates' stamp: ''!
validTestTemplate
	"Template used to create the test methods for valid tests
	<1s> = test name
	 <2s> = test ID
	 <3s> = description
	 <4s> = XML spec reference
	 <5s> = test path
	 <6s> = answer file path" 
	^'test<1s>
	"<3s>
	 See XML Spec. 1.0 section: <4s>"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: ''<2s>''])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:''<6s>'')  contentsOfEntireFile.

	[result := self runTest: ''<5s>'' ]
		on: VWXMLWarningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: ''<2s>'')
		ifTrue:[result := result copyReplaceAll: ''&#13;'' with: ''&#10;'' ].
	self assert: correctAnswer = result.'


"	correctAnswer := ((self class filenameAt:''<6s>'') withEncoding: #UTF_8 ) readStream contents."! !

!XMLParserTests class methodsFor: 'test generation' stamp: 'mir 1/7/2002 17:29'!
xmlTestDriverIn: aTailPathString
	"Return an array of VWXMLElements containing the test"
	| document driverText mainElement |

	"Parser can not handle comments in files, but can handle them in strings
	 The above problem has been fixed, so could have the parser open the file.
	 Will keep this code for those that have not installed my fixes"
	driverText := (self filenameAt: aTailPathString) contentsOfEntireFile.
	document := self parserClass 
		processDocumentString: driverText
	 	beforeScanDo: [:parser | parser validate: false].

	"filter out the comments. There is only one top level element in an XML document"
	mainElement := (document selectNodes: [:each | each isElement] ) at: 1.
	^mainElement elementsNamed: 'TEST'! !

!XMLParserTests methodsFor: 'asserting' stamp: ''!
assert: aBlock raises: anException 
	"assert that the block will raise an exception - the new exceptions, not an old style signal"

	aBlock on: anException do: [:exeption | ^nil].
	TestResult failure 
		signal: 'Should have raised ' , anException printString! !

!XMLParserTests methodsFor: 'private' stamp: ''!
canonicalVersion: aDocument
	|  aStream |
	aStream := WriteStream on: (String new: 10).
	aDocument
		printCanonicalOn: aStream.

	^aStream contents! !

!XMLParserTests methodsFor: 'private' stamp: 'mir 11/23/2007 18:53'!
exceptionSet
	^SAXParseException , SAXMalformedException, SAXWarning! !

!XMLParserTests methodsFor: 'private' stamp: 'mir 11/23/2007 18:53'!
exceptionSet2
	^SAXParseException , SAXMalformedException , SAXWarning! !

!XMLParserTests methodsFor: 'initialize' stamp: ''!
initialize
	testsToSkip := self class allTestsToSkip.! !

!XMLParserTests methodsFor: 'private' stamp: 'mir 1/7/2002 16:40'!
parserClass
	^Smalltalk at: self parserClassName! !

!XMLParserTests methodsFor: 'private' stamp: 'mir 11/23/2007 18:53'!
parserClassName
	^#XMLDOMParser! !

!XMLParserTests methodsFor: 'private' stamp: 'mir 11/23/2007 18:53'!
runTest: partialPath 
	| test testFile |
	testFile := self class filenameAt: partialPath.
	[test := self parserClass parseDocumentFrom: testFile]
		ensure: [testFile close].
	^self canonicalVersion: test.! !

!XMLParserTests methodsFor: 'private' stamp: 'mir 11/23/2007 18:53'!
warningSignal
	^SAXWarning! !

XMLParserTests subclass: #XMLParserTestsClark
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-Testing'!

!XMLParserTestsClark commentStamp: '<historical>' prior: 0!
'Class Author: Roger Whitney whitney@cs.sdsu.edu
Version 2.0
April 22, 2000

XMLParserTestsClark uses XML tests by James Clark, Sun, and OASIS. These tests are distributed as test suite by OASIS at: 
http://www.oasis-open.org/committees/xmltest/xmlconf-19990712.zip This link can be found on the page:
http://www.oasis-open.org/committees/xmltest/testsuite.htm. 

To run the test suite you must:
	Install the OASIS test suite on your hard drive
	Edit the class method baseTestDirectory to include the full path of the directory containing the OASIS test suite.
	install Sunit.
	Run the tests the standard way: TestRunner open

The VWXMPParser does not pass all tests.  OX''s release 1.2 of Cincom''s XML parser fails about 40 tests out of about 800. This classs is configured to allow you to turn some of the tests off. The class method allTestsToSkip returns an OrderedCollection of tests that can be skiped. The tests are identified using the test ID given in the files oasis/oasis.xml, xmltest/xmltest.xml, sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml which located in the OASIS test suite. The class method skipKnownBadTests determines if the tests are skipped. The class method shouldConvertCR: determines if a test should convert the cr in the Cincom''s parsers output to lf. 

The test methods in this class are generated by class methods from files in the OASIS test suite which catalog the tests (oasis/oasis.xml, xmltest/xmltest.xml, sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml) If you wish to generate the test methods, you must edit the files sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml. They need a top-level tag to enclose the entire file. It does not matter what the tag is.

Reasons the Parser fails tests

carriage return(cr) vs line feed(lf)
	The XML spec requires all carriage returns and cr-lf pairs to be converted to lf. 
	Smalltalk strings use cr, as does the parser.

Unicode characters 
	The parser fails all/nearly all test with unicode characters. The problem is in the tests. The tests
	are not reading the answer files using UFT-8 format.

Accepts attributes with out space between them

Unicode characters with large numerical value throws an exception when stored in a stream in parser

Parser does not check for incomplete uri's
Parser does not include NOTATION elements in its tree structure
Parser does not check for valid language identification
Parser does not check for validity constraints to make a document standalone
Parser does not check name of the top level element
Parser does not check for encoding declaration in Text declarations
!

!XMLParserTestsClark class methodsFor: 'tests to skip' stamp: 'mir 11/23/2007 19:04'!
allTestsToSkip
	
	^#( "invalid test"
		'valid-sa-012'	
		'valid-sa-105' " the answer the test gives seems incorrect, and parser seems correct"	

		"encoding problems"
"		'valid-sa-049' 'valid-sa-050' 'valid-sa-051' 'valid-sa-061' 'valid-sa-062'
		'valid-sa-063'  'valid-ext-sa-014'"
		"no space between attributes"
		'not-wf-ext-sa-001' 'not-wf-sa-186'

		"Too many cr in parsers answer"
		'valid-sa-093'

		"illegal PE in DTD"
		'valid-sa-094'

		"cr problem should return an entity"
		'valid-sa-107'  'valid-sa-106' 
		)! !

!XMLParserTestsClark methodsFor: 'clark invalid' stamp: ''!
testclarkinvalid001
	"
    Tests the  Proper Declaration/PE Nesting  validity constraint by
    fragmenting a comment between two parameter entities.
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'invalid--001'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/invalid/001.xml']
		raises: self exceptionSet! !

!XMLParserTestsClark methodsFor: 'clark invalid' stamp: ''!
testclarkinvalid002
	"
    Tests the  Proper Group/PE Nesting  validity constraint by
    fragmenting a content model between two parameter entities.
	 See XML Spec. 1.0 section: 3.2.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'invalid--002'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/invalid/002.xml']
		raises: self exceptionSet! !

!XMLParserTestsClark methodsFor: 'clark invalid' stamp: ''!
testclarkinvalid003
	"
    Tests the  Proper Declaration/PE Nesting  validity constraint by
    fragmenting an entity declaration between two parameter entities.
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'invalid--003'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/invalid/003.xml']
		raises: self exceptionSet! !

!XMLParserTestsClark methodsFor: 'clark invalid' stamp: ''!
testclarkinvalid004
	"
    Tests the  Proper Declaration/PE Nesting  validity constraint by
    fragmenting an entity declaration between three parameter entities.
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'invalid--004'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/invalid/004.xml']
		raises: self exceptionSet! !

!XMLParserTestsClark methodsFor: 'clark invalid' stamp: ''!
testclarkinvalid005
	"
    Tests the  Proper Declaration/PE Nesting  validity constraint by
    fragmenting an entity declaration between two parameter entities.
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'invalid--005'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/invalid/005.xml']
		raises: self exceptionSet! !

!XMLParserTestsClark methodsFor: 'clark invalid' stamp: ''!
testclarkinvalid006
	"
    Tests the  Proper Declaration/PE Nesting  validity constraint by
    fragmenting an entity declaration between two parameter entities.
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'invalid--006'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/invalid/006.xml']
		raises: self exceptionSet! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfextsa001
	"
    Tests the No Recursion WFC by having an external general
    entity be self-recursive.
	 See XML Spec. 1.0 section: 4.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-ext-sa-001'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/ext-sa/001.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfextsa002
	"
    External entities have  text declarations , which do
    not permit the  standalone=...  attribute that's allowed
    in XML declarations.
	 See XML Spec. 1.0 section: 4.3.1 4.3.2 [77, 78]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-ext-sa-002'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/ext-sa/002.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfextsa003
	"
    Only one text declaration is permitted; a second one
    looks like an illegal processing instruction (target names
    of  xml  in any case are not allowed). 
	 See XML Spec. 1.0 section: 2.6 [17]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-ext-sa-003'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/ext-sa/003.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfnotsa001
	"
    Conditional sections must be properly terminated ( ]>  used
    instead of  ]]> ). 
	 See XML Spec. 1.0 section: 3.4 [62]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-not-sa-001'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/not-sa/001.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfnotsa002
	"
    Processing instruction target names may not be  XML  
    in any combination of cases. 
	 See XML Spec. 1.0 section: 2.6 [17]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-not-sa-002'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/not-sa/002.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfnotsa003
	"
    Conditional sections must be properly terminated ( ]]>  omitted). 
	 See XML Spec. 1.0 section: 3.4 [62]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-not-sa-003'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/not-sa/003.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfnotsa004
	"
    Conditional sections must be properly terminated ( ]]>  omitted). 
	 See XML Spec. 1.0 section: 3.4 [62]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-not-sa-004'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/not-sa/004.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark invalid' stamp: ''!
testclarknotwfnotsa005
	"
    Tests the Entity Declared VC by referring to an
    undefined parameter entity within an external entity.
	 See XML Spec. 1.0 section: 4.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-not-sa-005'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/not-sa/005.xml']
		raises: self exceptionSet! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfnotsa006
	"
    Conditional sections need a '[' after the INCLUDE or IGNORE. 
	 See XML Spec. 1.0 section: 3.4 [62]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-not-sa-006'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/not-sa/006.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfnotsa007
	"
    A <!!DOCTYPE ...> declaration may not begin any external
    entity; it's only found once, in the document entity.
	 See XML Spec. 1.0 section: 4.3.2 [79]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-not-sa-007'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/not-sa/007.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfnotsa008
	"
    In DTDs, the '%' character must be part of a parameter
    entity reference.
	 See XML Spec. 1.0 section: 4.1 [69]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-not-sa-008'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/not-sa/008.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa001
	"
    Attribute values must start with attribute names, not  ? . 
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-001'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/001.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa002
	"
    Names may not start with  . ; it's not a Letter. 
	 See XML Spec. 1.0 section: 2.3 [4]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-002'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/002.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa003
	"
    Processing Instruction target name is required.
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-003'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/003.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa004
	"
    SGML-ism:  processing instructions end in '?>' not '>'. 
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-004'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/004.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa005
	"
    Processing instructions end in '?>' not '?'. 
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-005'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/005.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa006
	"
    XML comments may not contain  --  
	 See XML Spec. 1.0 section: 2.5 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-006'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/006.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa007
	"
    General entity references have no whitespace after the
    entity name and before the semicolon. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-007'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/007.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa008
	"
    Entity references must include names, which don't begin
    with '.' (it's not a Letter or other name start character). 
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-008'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/008.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa009
	"
    Character references may have only decimal or numeric strings.
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-009'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/009.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa010
	"
    Ampersand may only appear as part of a general entity reference.
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-010'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/010.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa011
	"
    SGML-ism:  attribute values must be explicitly assigned a
    value, it can't act as a boolean toggle. 
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-011'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/011.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa012
	"
    SGML-ism:  attribute values must be quoted in all cases. 
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-012'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/012.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa013
	"
    The quotes on both ends of an attribute value must match. 
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-013'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/013.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa014
	"
    Attribute values may not contain literal '<' characters. 
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-014'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/014.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa015
	"
    Attribute values need a value, not just an equals sign. 
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-015'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/015.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa016
	"
    Attribute values need an associated name.
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-016'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/016.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa017
	"
    CDATA sections need a terminating ']]>'. 
	 See XML Spec. 1.0 section: 2.7 [18]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-017'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/017.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa018
	"
    CDATA sections begin with a literal '<!![CDATA[', no space.
	 See XML Spec. 1.0 section: 2.7 [19]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-018'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/018.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa019
	"
    End tags may not be abbreviated as '</>'.
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-019'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/019.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa020
	"
    Attribute values may not contain literal '&'
    characters except as part of an entity reference. 
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-020'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/020.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa021
	"
    Attribute values may not contain literal '&'
    characters except as part of an entity reference. 
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-021'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/021.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa022
	"
    Character references end with semicolons, always!!
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-022'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/022.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa023
	"
    Digits are not valid name start characters. 
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-023'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/023.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa024
	"
    Digits are not valid name start characters. 
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-024'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/024.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa025
	"
    Text may not contain a literal ']]>' sequence. 
	 See XML Spec. 1.0 section: 2.4 [14]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-025'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/025.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa026
	"
    Text may not contain a literal ']]>' sequence. 
	 See XML Spec. 1.0 section: 2.4 [14]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-026'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/026.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa027
	"
    Comments must be terminated with  --> .
	 See XML Spec. 1.0 section: 2.5 [15]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-027'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/027.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa028
	"
    Processing instructions must end with '?>'. 
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-028'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/028.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa029
	"
    Text may not contain a literal ']]>' sequence. 
	 See XML Spec. 1.0 section: 2.4 [14]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-029'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/029.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa030
	"
    A form feed is not a legal XML character. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-030'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/030.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa031
	"
    A form feed is not a legal XML character. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-031'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/031.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa032
	"
    A form feed is not a legal XML character. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-032'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/032.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa033
	"
    An ESC (octal 033) is not a legal XML character. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-033'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/033.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa034
	"
    A form feed is not a legal XML character. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-034'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/034.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa035
	"
    The '<' character is a markup delimiter and must
    start an element, CDATA section, PI, or comment. 
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-035'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/035.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa036
	"
    Text may not appear after the root element. 
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-036'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/036.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa037
	"
    Character references may not appear after the root element. 
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-037'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/037.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa038
	"
    Tests the  Unique Att Spec  WF constraint by providing
    multiple values for an attribute.
	 See XML Spec. 1.0 section: 3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-038'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/038.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa039
	"
    Tests the Element Type Match WFC - end tag name must
    match start tag name.
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-039'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/039.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa040
	"
    Provides two document elements.
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-040'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/040.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa041
	"
    Provides two document elements.
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-041'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/041.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa042
	"
     Invalid End Tag 
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-042'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/042.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa043
	"
    Provides #PCDATA text after the document element. 
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-043'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/043.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa044
	"
    Provides two document elements.
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-044'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/044.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa045
	"
    Invalid Empty Element Tag 
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-045'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/045.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa046
	"
    This start (or empty element) tag was not terminated correctly. 
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-046'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/046.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa047
	"
    Invalid empty element tag invalid whitespace 
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-047'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/047.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa048
	"
    Provides a CDATA section after the roor element.
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-048'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/048.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa049
	"
    Missing start tag 
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-049'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/049.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa050
	"
    Empty document, with no root element. 
	 See XML Spec. 1.0 section: 2.1 [1]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-050'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/050.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa051
	"
     CDATA is invalid at top level of document.
	 See XML Spec. 1.0 section: 2.7 [18]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-051'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/051.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa052
	"
    Invalid character reference. 
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-052'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/052.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa053
	"
    End tag does not match start tag. 
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-053'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/053.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa054
	"
     PUBLIC requires two literals.
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-054'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/054.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa055
	"
    Invalid Document Type Definition format. 
	 See XML Spec. 1.0 section: 2.8 [28]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-055'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/055.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa056
	"
    Invalid Document Type Definition format - misplaced comment. 
	 See XML Spec. 1.0 section: 2.8 [28]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-056'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/056.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa057
	"
    This isn't SGML; comments can't exist in declarations. 
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-057'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/057.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa058
	"
    Invalid character , in ATTLIST enumeration 
	 See XML Spec. 1.0 section: 3.3.1 [54]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-058'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/058.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa059
	"
    String literal must be in quotes. 
	 See XML Spec. 1.0 section: 3.3.1 [59]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-059'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/059.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa060
	"
     Invalid type NAME defined in ATTLIST.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-060'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/060.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa061
	"
    External entity declarations require whitespace between public
    and system IDs.
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-061'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/061.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa062
	"
    Entity declarations need space after the entity name. 
	 See XML Spec. 1.0 section: 4.2 [71]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-062'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/062.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa063
	"
    Conditional sections may only appear in the external
    DTD subset. 
	 See XML Spec. 1.0 section: 2.8 [29]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-063'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/063.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa064
	"
    Space is required between attribute type and default values
    in <!!ATTLIST...> declarations. 
	 See XML Spec. 1.0 section: 3.3 [53]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-064'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/064.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa065
	"
    Space is required between attribute name and type
    in <!!ATTLIST...> declarations. 
	 See XML Spec. 1.0 section: 3.3 [53]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-065'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/065.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa066
	"
    Required whitespace is missing. 
	 See XML Spec. 1.0 section: 3.3 [52]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-066'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/066.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa067
	"
    Space is required between attribute type and default values
    in <!!ATTLIST...> declarations. 
	 See XML Spec. 1.0 section: 3.3 [53]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-067'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/067.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa068
	"
    Space is required between NOTATION keyword and list of
    enumerated choices in <!!ATTLIST...> declarations. 
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-068'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/068.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa069
	"
    Space is required before an NDATA entity annotation.
	 See XML Spec. 1.0 section: 4.2.2 [76]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-069'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/069.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa070
	"
    XML comments may not contain  --  
	 See XML Spec. 1.0 section: 2.5 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-070'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/070.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa071
	"
     ENTITY can't reference itself directly or indirectly.
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-071'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/071.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa072
	"
    Undefined ENTITY foo. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-072'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/072.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa073
	"
    Undefined ENTITY f. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-073'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/073.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa074
	"
    Internal general parsed entities are only well formed if
    they match the  content  production. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-074'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/074.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa075
	"
    ENTITY can't reference itself directly or indirectly. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-075'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/075.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa076
	"
    Undefined ENTITY foo. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-076'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/076.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa077
	"
    Undefined ENTITY bar. 
	 See XML Spec. 1.0 section: 41. [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-077'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/077.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa078
	"
    Undefined ENTITY foo. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-078'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/078.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa079
	"
    ENTITY can't reference itself directly or indirectly. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-079'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/079.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa080
	"
    ENTITY can't reference itself directly or indirectly. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-080'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/080.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa081
	"
    This tests the No External Entity References WFC,
    since the entity is referred to within an attribute.  
	 See XML Spec. 1.0 section: 3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-081'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/081.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa082
	"
    This tests the No External Entity References WFC,
    since the entity is referred to within an attribute.  
	 See XML Spec. 1.0 section: 3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-082'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/082.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa083
	"
    Undefined NOTATION n. 
	 See XML Spec. 1.0 section: 4.2.2 [76]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-083'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/083.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa084
	"
    Tests the Parsed Entity WFC by referring to an
    unparsed entity.  (This precedes the error of not declaring
    that entity's notation, which may be detected any time before
    the DTD parsing is completed.) 
	 See XML Spec. 1.0 section: 4.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-084'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/084.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa085
	"
    Public IDs may not contain  [ . 
	 See XML Spec. 1.0 section: 2.3 [13]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-085'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/085.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa086
	"
    Public IDs may not contain  [ . 
	 See XML Spec. 1.0 section: 2.3 [13]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-086'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/086.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa087
	"
    Public IDs may not contain  [ . 
	 See XML Spec. 1.0 section: 2.3 [13]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-087'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/087.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa088
	"
    Attribute values are terminated by literal quote characters,
    and any entity expansion is done afterwards. 
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-088'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/088.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa089
	"
    Parameter entities  are  always parsed; NDATA annotations
    are not permitted.
	 See XML Spec. 1.0 section: 4.2 [74]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-089'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/089.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa090
	"
    Attributes may not contain a literal  <  character;
    this one has one because of reference expansion. 
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-090'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/090.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa091
	"
    Parameter entities  are  always parsed; NDATA annotations
    are not permitted.
	 See XML Spec. 1.0 section: 4.2 [74]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-091'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/091.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa092
	"
    The replacement text of this entity has an illegal reference,
    because the character reference is expanded immediately. 
	 See XML Spec. 1.0 section: 4.5"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-092'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/092.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa093
	"
    Hexadecimal character references may not use the uppercase 'X'.
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-093'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/093.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa094
	"
    Prolog VERSION must be lowercase. 
	 See XML Spec. 1.0 section: 2.8 [24]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-094'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/094.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa095
	"
    VersionInfo must come before EncodingDecl. 
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-095'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/095.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa096
	"
    Space is required before the standalone declaration. 
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-096'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/096.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa097
	"
    Both quotes surrounding VersionNum must be the same. 
	 See XML Spec. 1.0 section: 2.8 [24]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-097'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/097.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa098
	"
    Only one  version=...  string may appear in an XML declaration.
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-098'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/098.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa099
	"
    Only three pseudo-attributes are in the XML declaration,
    and  valid=...  is not one of them. 
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-099'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/099.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa100
	"
    Only  yes  and  no  are permitted as values of  standalone . 
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-100'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/100.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa101
	"
    Space is not permitted in an encoding name. 
	 See XML Spec. 1.0 section: 4.3.3 [81]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-101'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/101.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa102
	"
    Provides an illegal XML version number; spaces are illegal.
	 See XML Spec. 1.0 section: 2.8 [26]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-102'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/102.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa103
	"
    End-tag required for element foo. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-103'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/103.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa104
	"
    Internal general parsed entities are only well formed if
    they match the  content  production. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-104'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/104.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa105
	"
    Invalid placement of CDATA section. 
	 See XML Spec. 1.0 section: 2.7 "

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-105'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/105.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa106
	"
    Invalid placement of entity declaration. 
	 See XML Spec. 1.0 section: 4.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-106'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/106.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa107
	"
     Invalid document type declaration.  CDATA alone is invalid.
	 See XML Spec. 1.0 section: 2.8 [28]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-107'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/107.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa108
	"
    No space in '<!![CDATA['.
	 See XML Spec. 1.0 section: 2.7 [19]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-108'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/108.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa109
	"
    Tags invalid within EntityDecl. 
	 See XML Spec. 1.0 section: 4.2 [70]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-109'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/109.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa110
	"
    Entity reference must be in content of element. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-110'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/110.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa111
	"
    Entiry reference must be in content of element not Start-tag. 
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-111'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/111.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa112
	"
    CDATA sections start '<!![CDATA[', not '<!!cdata['.
	 See XML Spec. 1.0 section: 2.7 [19]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-112'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/112.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa113
	"
    Parameter entity values must use valid reference syntax;
    this reference is malformed.
	 See XML Spec. 1.0 section: 2.3 [9]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-113'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/113.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa114
	"
    General entity values must use valid reference syntax;
    this reference is malformed.
	 See XML Spec. 1.0 section: 2.3 [9]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-114'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/114.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa115
	"
    The replacement text of this entity is an illegal character
    reference, which must be rejected when it is parsed in the
    context of an attribute value.
	 See XML Spec. 1.0 section: 4.5"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-115'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/115.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa116
	"
    Internal general parsed entities are only well formed if
    they match the  content  production.  This is a partial
    character reference, not a full one. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-116'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/116.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa117
	"
    Internal general parsed entities are only well formed if
    they match the  content  production.  This is a partial
    character reference, not a full one. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-117'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/117.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa118
	"
    Entity reference expansion is not recursive.
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-118'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/118.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa119
	"
    Internal general parsed entities are only well formed if
    they match the  content  production.  This is a partial
    character reference, not a full one. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-119'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/119.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa120
	"
    Character references are expanded in the replacement text of
    an internal entity, which is then parsed as usual.  Accordingly,
    & must be doubly quoted - encoded either as &amp;
    or as &#38;#38;. 
	 See XML Spec. 1.0 section: 4.5"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-120'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/120.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa121
	"
    A name of an ENTITY was started with an invalid character. 
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-121'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/121.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa122
	"
    Invalid syntax mixed connectors are used. 
	 See XML Spec. 1.0 section: 3.2.1 [47]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-122'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/122.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa123
	"
    Invalid syntax mismatched parenthesis. 
	 See XML Spec. 1.0 section: 3.2.1 [48]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-123'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/123.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa124
	"
    Invalid format of Mixed-content declaration. 
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-124'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/124.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa125
	"
    Invalid syntax extra set of parenthesis not necessary. 
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-125'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/125.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa126
	"
    Invalid syntax Mixed-content must be defined as zero or more. 
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-126'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/126.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa127
	"
    Invalid syntax Mixed-content must be defined as zero or more. 
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-127'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/127.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa128
	"
    Invalid CDATA syntax. 
	 See XML Spec. 1.0 section: 2.7 [18]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-128'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/128.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa129
	"
    Invalid syntax for Element Type Declaration. 
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-129'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/129.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa130
	"
    Invalid syntax for Element Type Declaration. 
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-130'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/130.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa131
	"
    Invalid syntax for Element Type Declaration. 
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-131'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/131.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa132
	"
    Invalid syntax mixed connectors used. 
	 See XML Spec. 1.0 section: 3.2.1 [50]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-132'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/132.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa133
	"
    Illegal whitespace before optional character causes syntax error. 
	 See XML Spec. 1.0 section: 3.2.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-133'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/133.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa134
	"
    Illegal whitespace before optional character causes syntax error. 
	 See XML Spec. 1.0 section: 3.2.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-134'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/134.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa135
	"
    Invalid character used as connector. 
	 See XML Spec. 1.0 section: 3.2.1 [47]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-135'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/135.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa136
	"
    Tag omission is invalid in XML. 
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-136'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/136.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa137
	"
    Space is required before a content model. 
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-137'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/137.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa138
	"
    Invalid syntax for content particle.  
	 See XML Spec. 1.0 section: 3.2.1 [48]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-138'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/138.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa139
	"
    The element-content model should not be empty. 
	 See XML Spec. 1.0 section: 3.2.1 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-139'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/139.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa140
	"
    Character '&#x309a;' is a CombiningChar, not a
    Letter, and so may not begin a name.
	 See XML Spec. 1.0 section: 2.3 [4]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-140'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/140.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa141
	"
    Character #x0E5C is not legal in XML names. 
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-141'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/141.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa142
	"
    Character #x0000 is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-142'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/142.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa143
	"
    Character #x001F is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-143'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/143.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa144
	"
    Character #xFFFF is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-144'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/144.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa145
	"
    Character #xD800 is not legal anywhere in an XML document.  (If it
    appeared in a UTF-16 surrogate pair, it'd represent half of a UCS-4
    character and so wouldn't really be in the document.) 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-145'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/145.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa146
	"
    Character references must also refer to legal XML characters;
    #x00110000 is one more than the largest legal character.
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-146'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/146.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa147
	"
    XML Declaration may not be preceded by whitespace.
	 See XML Spec. 1.0 section: 2.8 [22]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-147'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/147.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa148
	"
    XML Declaration may not be preceded by comments or whitespace.
	 See XML Spec. 1.0 section: 2.8 [22]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-148'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/148.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa149
	"
    XML Declaration may not be within a DTD.
	 See XML Spec. 1.0 section: 2.8 [28]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-149'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/149.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa150
	"
    XML declarations may not be within element content. 
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-150'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/150.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa151
	"
    XML declarations may not follow document content.
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-151'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/151.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa152
	"
    XML declarations must include the  version=...  string.
	 See XML Spec. 1.0 section: 2.8 [22]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-152'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/152.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa153
	"
    Text declarations may not begin internal parsed entities;
    they may only appear at the beginning of external parsed
    (parameter or general) entities. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-153'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/153.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa154
	"
    '<?XML ...?>' is neither an XML declaration
    nor a legal processing instruction target name. 
	 See XML Spec. 1.0 section: 2.8 2.6 [23, 17]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-154'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/154.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa155
	"
    '<?xmL ...?>' is neither an XML declaration
    nor a legal processing instruction target name. 
	 See XML Spec. 1.0 section: 2.8 2.6 [23, 17]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-155'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/155.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa156
	"
    '<?xMl ...?>' is neither an XML declaration
    nor a legal processing instruction target name. 
	 See XML Spec. 1.0 section: 2.8 2.6 [23, 17]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-156'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/156.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa157
	"
    '<?xmL ...?>' is not a legal processing instruction
    target name. 
	 See XML Spec. 1.0 section: 2.6 [17]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-157'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/157.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa158
	"
    SGML-ism:   #NOTATION gif  can't have attributes. 
	 See XML Spec. 1.0 section: 3.3 [52]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-158'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/158.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa159
	"
    Uses '&' unquoted in an entity declaration,
    which is illegal syntax for an entity reference.
	 See XML Spec. 1.0 section: 2.3 [9]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-159'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/159.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa160
	"
    Violates the PEs in Internal Subset WFC
    by using a PE reference within a declaration. 
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-160'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/160.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa161
	"
    Violates the PEs in Internal Subset WFC
    by using a PE reference within a declaration. 
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-161'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/161.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa162
	"
    Violates the PEs in Internal Subset WFC
    by using a PE reference within a declaration. 
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-162'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/162.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa163
	"
    Invalid placement of Parameter entity reference. 
	 See XML Spec. 1.0 section: 4.1 [69]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-163'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/163.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa164
	"
    Invalid placement of Parameter entity reference. 
	 See XML Spec. 1.0 section: 4.1 [69]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-164'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/164.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa165
	"
    Parameter entity declarations must have a space before
    the '%'. 
	 See XML Spec. 1.0 section: 4.2 [72]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-165'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/165.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa166
	"
    Character FFFF is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-166'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/166.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa167
	"
    Character FFFE is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-167'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/167.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa168
	"
    An unpaired surrogate (D800) is not legal anywhere
    in an XML document.
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-168'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/168.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa169
	"
    An unpaired surrogate (DC00) is not legal anywhere
    in an XML document.
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-169'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/169.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa170
	"
    Four byte UTF-8 encodings can encode UCS-4 characters
    which are beyond the range of legal XML characters
    (and can't be expressed in Unicode surrogate pairs).
    This document holds such a character.  
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-170'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/170.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa171
	"
    Character FFFF is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-171'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/171.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa172
	"
    Character FFFF is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-172'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/172.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa173
	"
    Character FFFF is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-173'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/173.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa174
	"
    Character FFFF is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-174'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/174.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa175
	"
    Character FFFF is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-175'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/175.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa176
	"
    Start tags must have matching end tags.
	 See XML Spec. 1.0 section: 3 [39]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-176'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/176.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa177
	"
    Character FFFF is not legal anywhere in an XML document. 
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-177'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/177.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa178
	"
    Invalid syntax matching double quote is missing. 
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-178'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/178.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa179
	"
    Invalid syntax matching double quote is missing. 
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-179'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/179.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa180
	"
    The Entity Declared WFC requires entities to be declared
    before they are used in an attribute list declaration. 
	 See XML Spec. 1.0 section: 4.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-180'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/180.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa181
	"
    Internal parsed entities must match the content
    production to be well formed. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-181'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/181.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa182
	"
    Internal parsed entities must match the content
    production to be well formed. 
	 See XML Spec. 1.0 section: 4.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-182'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/182.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa183
	"
    Mixed content declarations may not include content particles.
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-183'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/183.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa184
	"
    In mixed content models, element names must not be
    parenthesized. 
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-184'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/184.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa185
	"
    Tests the Entity Declared WFC.
    Note:  a nonvalidating parser is permitted not to report
    this WFC violation, since it would need to read an external
    parameter entity to distinguish it from a violation of
    the Standalone Declaration VC.
	 See XML Spec. 1.0 section: 4.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-185'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/185.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarknotwfsa186
	"
    Whitespace is required between attribute/value pairs. 
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'not-wf-sa-186'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/not-wf/sa/186.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa001
	"
    A combination of carriage return line feed in an external entity must
    be normalized to a single newline. 
	 See XML Spec. 1.0 section: 2.11"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-001'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/001.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/001.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-001')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa002
	"
    A carriage return (also CRLF) in an external entity must
    be normalized to a single newline. 
	 See XML Spec. 1.0 section: 2.11"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-002'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/002.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/002.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-002')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa003
	"
    Test demonstrates that the content of an element can be empty. In this case the external entity is an empty file. 
	 See XML Spec. 1.0 section: 3.1 4.1 [43] [68]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-003'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/003.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/003.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-003')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa004
	"
    A carriage return (also CRLF) in an external entity must
    be normalized to a single newline. 
	 See XML Spec. 1.0 section: 2.11"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-004'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/004.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/004.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-004')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa005
	"
    Test demonstrates the use of optional character and content particles within an element content.  The test also show the use of external entity. 
	 See XML Spec. 1.0 section: 3.2.1 4.2.2 [48] [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-005'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/005.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/005.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-005')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa006
	"
    Test demonstrates the use of optional character and content particles within mixed element content.  The test also shows the use of an external entity and that a carriage control line feed in an external entity must be normalized to a single newline. 
	 See XML Spec. 1.0 section: 2.11 3.2.1 3.2.2 4.2.2 [48] [51] [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-006'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/006.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/006.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-006')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa007
	"
    Test demonstrates the use of external entity and how replacement 
text is retrieved and processed. 
	 See XML Spec. 1.0 section: 4.2.2 4.4.3 [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-007'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/007.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/007.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-007')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa008
	" Test demonstrates the use of external 
entity and how replacement text is retrieved and processed.  Also tests the use of an 
EncodingDecl of UTF-16.
	 See XML Spec. 1.0 section: 4.2.2 4.3.3. 4.4.3 [75] [80]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-008'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/008.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/008.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-008')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa009
	"
    A carriage return (also CRLF) in an external entity must
    be normalized to a single newline. 
	 See XML Spec. 1.0 section: 2.11"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-009'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/009.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/009.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-009')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa011
	"
    Test demonstrates the use of a public identifier with and external entity.  
The test also show that a carriage control line feed combination in an external 
entity must be normalized to a single newline. 
	 See XML Spec. 1.0 section: 2.11 4.2.2 [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-011'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/011.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/011.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-011')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa012
	"
     Test demonstrates both internal and external entities and that processing of entity references may be required to produce the correct replacement text.
	 See XML Spec. 1.0 section: 4.2.1 4.2.2"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-012'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/012.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/012.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-012')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa013
	"
    Test demonstrates that whitespace is handled by adding a single whitespace to the normalized value in the attribute list. 
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-013'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/013.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/013.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-013')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidextsa014
	"
    Test demonstrates use of characters outside of normal ASCII range.
	 See XML Spec. 1.0 section: 4.1 4.4.3 [68]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-ext-sa-014'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/ext-sa/out/014.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/ext-sa/014.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-ext-sa-014')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa001
	"
    Test demonstrates the use of an ExternalID within a document type definition. 
	 See XML Spec. 1.0 section: 4.2.2 [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-001'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/001.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/001.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-001')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa002
	"
    Test demonstrates the use of an ExternalID within a document type definition. 
	 See XML Spec. 1.0 section: 4.2.2 [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-002'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/002.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/002.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-002')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa003
	"
    Test demonstrates the expansion of an external parameter entity that declares an attribute. 
	 See XML Spec. 1.0 section: 4.1 [69]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-003'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/003.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/003.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-003')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa004
	"
    Expands an external parameter entity in two different ways,
    with one of them declaring an attribute.
	 See XML Spec. 1.0 section: 4.1 [69]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-004'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/004.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/004.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-004')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa005
	"
    Test demonstrates the expansion of an external parameter entity that declares an attribute. 
	 See XML Spec. 1.0 section: 4.1 [69]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-005'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/005.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/005.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-005')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa006
	"
    Test demonstrates that when more than one definition is provided for the same attribute of a given element type only the first declaration is binding. 
	 See XML Spec. 1.0 section: 3.3 [52]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-006'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/006.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/006.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-006')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa007
	"
    Test demonstrates the use of an Attribute list declaration within an external entity. 
	 See XML Spec. 1.0 section: 3.3 [52]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-007'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/007.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/007.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-007')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa008
	"
    Test demonstrates that an external identifier may include a public identifier. 
	 See XML Spec. 1.0 section: 4.2.2 [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-008'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/008.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/008.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-008')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa009
	"
    Test demonstrates that an external identifier may include a public identifier. 
	 See XML Spec. 1.0 section: 4.2.2 [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-009'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/009.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/009.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-009')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa010
	"
    Test demonstrates that when more that one definition is provided for the same attribute of a given element type only the first declaration is binding. 
	 See XML Spec. 1.0 section: 3.3 [52]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-010'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/010.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/010.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-010')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa011
	"
    Test demonstrates a parameter entity declaration whose parameter entity definition is an ExternalID. 
	 See XML Spec. 1.0 section: 4.2 4.2.1 [72] [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-011'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/011.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/011.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-011')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa012
	"
    Test demonstrates an enternal parsed entity that begins with a text declaration. 
	 See XML Spec. 1.0 section: 4.3.1 [77]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-012'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/012.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/012.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-012')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa013
	"
    Test demonstrates the use of the conditional section INCLUDE that will include its contents as part of the DTD. 
	 See XML Spec. 1.0 section: 3.4 [62]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-013'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/013.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/013.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-013')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa014
	"
    Test demonstrates the use of the conditional section INCLUDE that will include its contents as part of the DTD.  The keyword is a parameter-entity reference. 
	 See XML Spec. 1.0 section: 3.4 [62]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-014'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/014.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/014.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-014')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa015
	"
    Test demonstrates the use of the conditonal section IGNORE the will ignore its content from being part of the DTD.  The keyword is a parameter-entity reference. 
	 See XML Spec. 1.0 section: 3.4 [63]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-015'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/015.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/015.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-015')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa016
	"
    Test demonstrates the use of the conditional section INCLUDE that will include its contents as part of the DTD.  The keyword is a parameter-entity reference.
	 See XML Spec. 1.0 section: 3.4 [62]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-016'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/016.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/016.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-016')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa017
	"
    Test demonstrates a parameter entity declaration that contains an attribute list declaration. 
	 See XML Spec. 1.0 section: 4.2 [72]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-017'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/017.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/017.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-017')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa018
	"
    Test demonstrates an EnternalID whose contents contain an parameter entity declaration and a attribute list definition. 
	 See XML Spec. 1.0 section: 4.2.2 [75]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-018'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/018.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/018.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-018')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa019
	"
    Test demonstrates that a parameter entity will be expanded with spaces on either side. 
	 See XML Spec. 1.0 section: 4.4.8"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-019'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/019.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/019.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-019')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa020
	"
    Parameter entities expand with spaces on either side.
	 See XML Spec. 1.0 section: 4.4.8"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-020'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/020.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/020.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-020')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa021
	"
    Test demonstrates a parameter entity declaration that contains a partial attribute list declaration. 
	 See XML Spec. 1.0 section: 4.2 [72]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-021'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/021.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/021.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-021')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa022
	"
    Test demonstrates the use of a parameter-entity reference as a keyword of a conditional section.  The parameter entity must be replaced by its content before the processor decides whether to include the conditional section. 
	 See XML Spec. 1.0 section: 3.4 [62]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-022'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/022.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/022.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-022')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa023
	"
    Test demonstrates the use of a parameter entity reference within an attribute list declaration.

	 See XML Spec. 1.0 section: 2.3 4.1 [10] [69]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-023'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/023.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/023.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-023')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa024
	"
    Constructs an <!!ATTLIST...> declaration from several PEs.
	 See XML Spec. 1.0 section: 2.8, 4.1 [69]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-024'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/024.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/024.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-024')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa025
	"
    Test demonstrates that when more that one definition is provided for the same entity only the first declaration is binding. 
	 See XML Spec. 1.0 section: 4.2"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-025'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/025.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/025.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-025')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa026
	"
    Test demonstrates that when more that one definition is provided for the same attribute of a given element type only the first declaration is binding. 
	 See XML Spec. 1.0 section: 3.3 [52]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-026'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/026.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/026.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-026')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa027
	"
    Test demonstrates a parameter entity reference whose value is NULL. 
	 See XML Spec. 1.0 section: 4.1 [69]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-027'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/027.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/027.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-027')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa028
	"
    Test demonstrates the use of the conditional section INCLUDE that will include its contents. 
	 See XML Spec. 1.0 section: 3.4 [62]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-028'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/028.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/028.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-028')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa029
	"
    Test demonstrates the use of the conditonal section IGNORE the will ignore its content from being used. 
	 See XML Spec. 1.0 section: 3.4 [62]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-029'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/029.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/029.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-029')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa030
	"
    Test demonstrates the use of the conditonal section IGNORE the will ignore its content from being used. 
	 See XML Spec. 1.0 section: 3.4 [62]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-030'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/030.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/030.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-030')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidnotsa031
	"
    Expands a general entity which contains a CDATA section with
    what looks like a markup declaration (but is just text since
    it's in a CDATA section).
	 See XML Spec. 1.0 section: 2.7"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-not-sa-031'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/not-sa/out/031.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/not-sa/031.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-not-sa-031')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa001
	"
    Test demonstrates an Element Type Declaration with Mixed Content. 
	 See XML Spec. 1.0 section: 3.2.2 [51]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-001'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/001.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/001.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-001')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa002
	"
    Test demonstrates that whitespace is permitted after the tag name in a Start-tag. 
	 See XML Spec. 1.0 section: 3.1 [40]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-002'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/002.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/002.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-002')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa003
	"
    Test demonstrates that whitespace is permitted after the tag name in an End-tag.
	 See XML Spec. 1.0 section: 3.1 [42]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-003'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/003.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/003.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-003')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa004
	"
    Test demonstrates a valid attribute specification within a Start-tag. 
	 See XML Spec. 1.0 section: 3.1 [41]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-004'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/004.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/004.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-004')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa005
	"
    Test demonstrates a valid attribute specification within a Start-tag that
contains whitespace on both sides of the equal sign. 
	 See XML Spec. 1.0 section: 3.1 [40]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-005'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/005.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/005.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-005')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa006
	"
    Test demonstrates that the AttValue within a Start-tag can use a single quote as a delimter. 
	 See XML Spec. 1.0 section: 3.1 [41]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-006'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/006.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/006.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-006')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa007
	"
    Test demonstrates numeric character references can be used for element content. 
	 See XML Spec. 1.0 section: 3.1 4.6 [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-007'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/007.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/007.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-007')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa008
	"
    Test demonstrates character references can be used for element content. 
	 See XML Spec. 1.0 section: 2.4 3.1 [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-008'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/008.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/008.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-008')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa009
	"
    Test demonstrates that PubidChar can be used for element content. 
	 See XML Spec. 1.0 section: 2.3 3.1 [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-009'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/009.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/009.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-009')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa010
	"
    Test demonstrates that whitespace is valid after the Attribute in a Start-tag. 
	 See XML Spec. 1.0 section: 3.1 [40]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-010'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/010.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/010.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-010')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa011
	"
    Test demonstrates mutliple Attibutes within the Start-tag. 
	 See XML Spec. 1.0 section: 3.1 [40]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-011'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/011.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/011.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-011')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa012
	"
    Uses a legal XML 1.0 name consisting of a single colon
    character (disallowed by the latest XML Namespaces draft).
	 See XML Spec. 1.0 section: 2.3 [4]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-012'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/012.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/012.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-012')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa013
	"
    Test demonstrates that the Attribute in a Start-tag can consist of numerals along with special characters. 
	 See XML Spec. 1.0 section: 2.3 3.1 [13] [40]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-013'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/013.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/013.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-013')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa014
	"
    Test demonstrates that all lower case letters are valid for the Attribute in a Start-tag. 
	 See XML Spec. 1.0 section: 2.3 3.1 [13] [40]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-014'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/014.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/014.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-014')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa015
	"
    Test demonstrates that all upper case letters are valid for the Attribute in a Start-tag. 
	 See XML Spec. 1.0 section: 2.3 3.1 [13] [40]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-015'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/015.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/015.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-015')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa016
	"
    Test demonstrates that Processing Instructions are valid element content. 
	 See XML Spec. 1.0 section: 2.6 3.1 [16] [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-016'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/016.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/016.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-016')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa017
	"
    Test demonstrates that Processing Instructions are valid element content and there can be more than one. 
	 See XML Spec. 1.0 section: 2.6 3.1 [16] [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-017'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/017.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/017.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-017')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa018
	"
    Test demonstrates that CDATA sections are valid element content. 
	 See XML Spec. 1.0 section: 2.7 3.1 [18] [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-018'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/018.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/018.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-018')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa019
	"
    Test demonstrates that CDATA sections are valid element content and that
ampersands may occur in their literal form. 
	 See XML Spec. 1.0 section: 2.7 3.1 [18] [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-019'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/019.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/019.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-019')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa020
	"
   Test demonstractes that CDATA sections are valid element content and that
everyting between the CDStart and CDEnd is recognized as character data not markup.  
	 See XML Spec. 1.0 section: 2.7 3.1 [18] [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-020'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/020.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/020.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-020')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa021
	"
    Test demonstrates that comments are valid element content. 
	 See XML Spec. 1.0 section: 2.5 3.1 [15] [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-021'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/021.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/021.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-021')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa022
	"
    Test demonstrates that comments are valid element content and that all characters before the double-hypen right angle combination are considered part of thecomment. 
	 See XML Spec. 1.0 section: 2.5 3.1 [15] [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-022'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/022.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/022.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-022')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa023
	"
    Test demonstrates that Entity References are valid element content. 
	 See XML Spec. 1.0 section: 3.1 [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-023'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/023.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/023.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-023')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa024
	"
    Test demonstrates that Entity References are valid element content and also demonstrates a valid Entity Declaration. 
	 See XML Spec. 1.0 section: 3.1 4.1 [43] [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-024'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/024.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/024.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-024')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa025
	"
    Test demonstrates an Element Type Declaration and that the contentspec can be of mixed content. 
	 See XML Spec. 1.0 section: 3.2 [46]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-025'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/025.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/025.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-025')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa026
	"
    Test demonstrates an Element Type Declaration and that EMPTY is a valid contentspec. 
	 See XML Spec. 1.0 section: 3.2 [46]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-026'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/026.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/026.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-026')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa027
	"
    Test demonstrates an Element Type Declaration and that ANY is a valid contenspec. 
	 See XML Spec. 1.0 section: 3.2 [46]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-027'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/027.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/027.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-027')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa028
	"
    Test demonstrates a valid prolog that uses double quotes as delimeters around the VersionNum. 
	 See XML Spec. 1.0 section: 2.8 [24]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-028'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/028.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/028.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-028')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa029
	"
    Test demonstrates a valid prolog that uses single quotes as delimters around the VersionNum. 
	 See XML Spec. 1.0 section: 2.8 [24]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-029'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/029.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/029.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-029')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa030
	"
    Test demonstrates a valid prolog that contains whitespace on both sides of the equal sign in the VersionInfo. 
	 See XML Spec. 1.0 section: 2.8 [25]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-030'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/030.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/030.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-030')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa031
	"
    Test demonstrates a valid EncodingDecl within the prolog. 
	 See XML Spec. 1.0 section: 4.3.3 [80]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-031'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/031.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/031.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-031')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa032
	"
    Test demonstrates a valid SDDecl within the prolog. 
	 See XML Spec. 1.0 section: 2.9 [32]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-032'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/032.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/032.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-032')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa033
	"
    Test demonstrates that both a EncodingDecl and SDDecl are valid within the prolog. 
	 See XML Spec. 1.0 section: 2.8 [23]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-033'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/033.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/033.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-033')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa034
	"
    Test demonstrates the correct syntax for an Empty element tag. 
	 See XML Spec. 1.0 section: 3.1 [44]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-034'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/034.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/034.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-034')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa035
	"
    Test demonstrates that whitespace is permissible after the name in an Empty element tag. 
	 See XML Spec. 1.0 section: 3.1 [44]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-035'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/035.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/035.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-035')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa036
	"
    Test demonstrates a valid processing instruction. 
	 See XML Spec. 1.0 section: 2.6 [16]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-036'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/036.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/036.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-036')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa037
	"
    Test demonstrates a valid comment and that it may appear anywhere in the document including at the end. 
	 See XML Spec. 1.0 section: 2.6 [15]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-037'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/037.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/037.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-037')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa038
	"
    Test demonstrates a valid comment and that it may appear anywhere in the document including the beginning. 
	 See XML Spec. 1.0 section: 2.6 [15]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-038'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/038.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/038.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-038')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa039
	"
    Test demonstrates a valid processing instruction and that it may appear at the beginning of the document. 
	 See XML Spec. 1.0 section: 2.6 [16]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-039'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/039.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/039.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-039')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa040
	"
    Test demonstrates an Attribute List declaration that uses a StringType as the AttType. 
	 See XML Spec. 1.0 section: 3.3 3.3.1 [52] [54]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-040'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/040.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/040.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-040')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa041
	"
    Test demonstrates an Attribute List declaration that uses a StringType as the AttType and also expands the CDATA attribute with a character reference. 
	 See XML Spec. 1.0 section: 3.3.1 4.1 [54] [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-041'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/041.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/041.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-041')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa042
	"
    Test demonstrates an Attribute List declaration that uses a StringType as the AttType and also expands the CDATA attribute with a character reference.  The test also shows that the leading zeros in the character reference are ignored. 
	 See XML Spec. 1.0 section: 3.3.1 4.1 [54] [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-042'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/042.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/042.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-042')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa043
	"
    An element's attributes may be declared before its content
    model; and attribute values may contain newlines.  
	 See XML Spec. 1.0 section: 3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-043'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/043.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/043.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-043')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa044
	"
    Test demonstrates that the empty-element tag must be use for an elements that are declared EMPTY. 
	 See XML Spec. 1.0 section: 3.1 [44]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-044'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/044.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/044.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-044')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa045
	"
    Tests whether more than one definition can be provided for the same attribute of a given element type with the first declaration being binding. 
	 See XML Spec. 1.0 section: 3.3 [52]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-045'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/045.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/045.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-045')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa046
	"
    Test demonstrates that when more than one AttlistDecl is provided for a given element type, the contents of all those provided are merged. 
	 See XML Spec. 1.0 section: 3.3 [52]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-046'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/046.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/046.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-046')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa047
	"
    Test demonstrates that extra whitespace is normalized into single space character. 
	 See XML Spec. 1.0 section: 3.1 [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-047'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/047.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/047.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-047')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa048
	"
    Test demonstrates that character data is valid element content. 
	 See XML Spec. 1.0 section: 2.4 3.1 [14] [43]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-048'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/048.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/048.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-048')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa049
	"
    Test demonstrates that characters outside of normal ascii range can be used as element content. 
	 See XML Spec. 1.0 section: 2.2 [2]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-049'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/049.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/049.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-049')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa050
	"
    Test demonstrates that characters outside of normal ascii range can be used as element content. 
	 See XML Spec. 1.0 section: 2.2 [2]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-050'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/050.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/050.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-050')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa051
	"
    The document is encoded in UTF-16 and uses some name
    characters well outside of the normal ASCII range.
    
	 See XML Spec. 1.0 section: 2.2 [2]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-051'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/051.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/051.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-051')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa053
	"
    Tests inclusion of a well-formed internal entity, which
    holds an element required by the content model.
	 See XML Spec. 1.0 section: 4.4.2"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-053'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/053.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/053.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-053')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa054
	"
    Test demonstrates that extra whitespace within Start-tags and End-tags are nomalized into single spaces. 
	 See XML Spec. 1.0 section: 3.1 [40] [42]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-054'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/054.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/054.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-054')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa055
	"
    Test demonstrates that extra whitespace within a processing instruction willnormalized into s single space character. 
	 See XML Spec. 1.0 section: 2.6 2.10 [16]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-055'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/055.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/055.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-055')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa056
	"
    Test demonstrates an Attribute List declaration that uses a StringType as the AttType and also expands the CDATA attribute with a character reference.  The test also shows that the leading zeros in the character reference are ignored. 
	 See XML Spec. 1.0 section: 3.3.1 4.1 [54] [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-056'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/056.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/056.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-056')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa057
	"
    Test demonstrates an element content model whose element can occur zero or more times. 
	 See XML Spec. 1.0 section: 3.2.1 [47]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-057'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/057.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/057.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-057')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa058
	"
    Test demonstrates that extra whitespace be normalized into a single space character in an attribute of type NMTOKENS. 
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-058'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/058.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/058.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-058')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa059
	"
    Test demonstrates an Element Type Declaration that uses the contentspec of EMPTY.  The element cannot have any contents and must always appear as an empty element in the document.  The test also shows an Attribute-list declaration with multiple AttDef's. 
	 See XML Spec. 1.0 section: 3.2 3.3 [46] [53]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-059'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/059.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/059.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-059')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa060
	"
    Test demonstrates the use of decimal Character References within element content. 
	 See XML Spec. 1.0 section: 4.1 [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-060'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/060.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/060.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-060')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa061
	"
    Test demonstrates the use of decimal Character References within element content. 
	 See XML Spec. 1.0 section: 4.1 [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-061'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/061.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/061.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-061')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa062
	"
    Test demonstrates the use of hexadecimal Character References within element.  
	 See XML Spec. 1.0 section: 4.1 [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-062'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/062.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/062.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-062')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa063
	"
    The document is encoded in UTF-8 and the name of the
    root element type uses non-ASCII characters.  
	 See XML Spec. 1.0 section: 2.3 [5]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-063'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/063.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/063.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-063')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa065
	"
    Tests ability to define an internal entity which can't
    legally be expanded (contains an unquoted <).
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-065'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/065.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/065.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-065')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa066
	"
    Expands a CDATA attribute with a character reference.
	 See XML Spec. 1.0 section: 4.1 [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-066'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/066.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/066.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-066')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa067
	"
    Test demonstrates the use of decimal character references within element content. 
	 See XML Spec. 1.0 section: 4.1 [66]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-067'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/067.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/067.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-067')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa068
	"
    Tests definition of an entity holding a carriage return character
    reference, which must be normalized to a newline before being
    reported to the application.
	 See XML Spec. 1.0 section: 2.11, 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-068'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/068.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/068.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-068')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa069
	"
    Verifies that an XML parser will parse a NOTATION
    declaration; the output phase of this test ensures that
    it's reported to the application. 
	 See XML Spec. 1.0 section: 4.7"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-069'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/069.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/069.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-069')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa070
	"
    Verifies that internal parameter entities are correctly
    expanded within the internal subset.
	 See XML Spec. 1.0 section: 4.4.8"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-070'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/070.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/070.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-070')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa071
	"
    Test demonstrates that an AttlistDecl can use ID as the TokenizedType within the Attribute type.  The test also shows that IMPLIED is a valid DefaultDecl. 
	 See XML Spec. 1.0 section: 3.3 3.3.1 [52] [56]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-071'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/071.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/071.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-071')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa072
	"
    Test demonstrates that an AttlistDecl can use IDREF as the TokenizedType within the Attribute type.  The test also shows that IMPLIED is a valid DefaultDecl. 
	 See XML Spec. 1.0 section: 3.3 3.3.1 [52] [56]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-072'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/072.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/072.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-072')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa073
	"
    Test demonstrates that an AttlistDecl can use IDREFS as the TokenizedType within the Attribute type.  The test also shows that IMPLIED is a valid DefaultDecl. 
	 See XML Spec. 1.0 section: 3.3 3.3.1 [52] [56]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-073'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/073.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/073.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-073')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa074
	"
    Test demonstrates that an AttlistDecl can use ENTITY as the TokenizedType within the Attribute type.  The test also shows that IMPLIED is a valid DefaultDecl. 
	 See XML Spec. 1.0 section: 3.3 3.3.1 [52] [56]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-074'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/074.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/074.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-074')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa075
	"
    Test demonstrates that an AttlistDecl can use ENTITIES as the TokenizedType within the Attribute type.  The test also shows that IMPLIED is a valid DefaultDecl. 
	 See XML Spec. 1.0 section: 3.3 3.3.1 [52] [56]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-075'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/075.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/075.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-075')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa076
	"
    Verifies that an XML parser will parse a NOTATION
    attribute; the output phase of this test ensures that
    both notations are reported to the application. 
	 See XML Spec. 1.0 section: 3.3.1"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-076'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/076.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/076.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-076')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa077
	"
    Test demonstrates that an AttlistDecl can use an EnumeratedType within the Attribute type.  The test also shows that IMPLIED is a valid DefaultDecl. 
	 See XML Spec. 1.0 section: 3.3 3.3.1 [52] [54]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-077'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/077.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/077.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-077')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa078
	"
    Test demonstrates that an AttlistDecl can use an StringType of CDATA within the Attribute type.  The test also shows that REQUIRED is a valid DefaultDecl. 
	 See XML Spec. 1.0 section: 3.3 3.3.1 [52] [54]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-078'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/078.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/078.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-078')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa079
	"
    Test demonstrates that an AttlistDecl can use an StringType of CDATA within the Attribute type.  The test also shows that FIXED is a valid DefaultDecl and that a value can be given to the attribute in the Start-tag as well as the AttListDecl. 
	 See XML Spec. 1.0 section: 3.3 3.3.2 [52] [60]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-079'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/079.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/079.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-079')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa080
	"
    Test demonstrates that an AttlistDecl can use an StringType of CDATA within the Attribute type.  The test also shows that FIXED is a valid DefaultDecl and that an value can be given to the attribute. 
	 See XML Spec. 1.0 section: 3.3 3.3.2 [52] [60]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-080'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/080.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/080.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-080')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa081
	"
    Test demonstrates the use of the optional character following a name or list  to govern the number of times an element or content particles in the list occur. 
	 See XML Spec. 1.0 section: 3.2.1 [50]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-081'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/081.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/081.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-081')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa082
	"
    Tests that an external PE may be defined (but not referenced).
	 See XML Spec. 1.0 section: 4.2 [72]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-082'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/082.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/082.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-082')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa083
	"
    Tests that an external PE may be defined (but not referenced).
	 See XML Spec. 1.0 section: 4.2 [72]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-083'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/083.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/083.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-083')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa084
	"
    Test demonstrates that although whitespace can be used to set apart markup for greater readability it is not necessary. 
	 See XML Spec. 1.0 section: 2.10"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-084'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/084.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/084.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-084')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa085
	"
    Parameter and General entities use different namespaces,
    so there can be an entity of each type with a given name.
	 See XML Spec. 1.0 section: 4"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-085'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/085.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/085.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-085')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa086
	"
    Tests whether entities may be declared more than once,
    with the first declaration being the binding one. 
	 See XML Spec. 1.0 section: 4.2"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-086'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/086.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/086.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-086')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa087
	"
    Tests whether character references in internal entities are
    expanded early enough, by relying on correct handling to
    make the entity be well formed.
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-087'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/087.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/087.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-087')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa088
	"
    Tests whether entity references in internal entities are
    expanded late enough, by relying on correct handling to
    make the expanded text be valid.  (If it's expanded too
    early, the entity will parse as an element that's not
    valid in that context.)
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-088'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/088.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/088.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-088')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa090
	"
    Verifies that an XML parser will parse a NOTATION
    attribute; the output phase of this test ensures that
    the notation is reported to the application. 
	 See XML Spec. 1.0 section: 3.3.1"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-090'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/090.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/090.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-090')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa091
	"
    Verifies that an XML parser will parse an ENTITY
    attribute; the output phase of this test ensures that
    the notation is reported to the application, and for
    validating parsers it further tests that the entity
    is so reported.
	 See XML Spec. 1.0 section: 3.3.1"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-091'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/091.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/091.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-091')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa092
	"
    Test demostrates that extra whitespace is normalized into a single space character. 
	 See XML Spec. 1.0 section: 2.3 2.10"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-092'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/092.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/092.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-092')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa093
	"
    Test demonstrates that extra whitespace is not intended for inclusion in the delivered version of the document. 
	 See XML Spec. 1.0 section: 2.10"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-093'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/093.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/093.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-093')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark not wf' stamp: ''!
testclarkvalidsa094
	"
    
    This refers to an undefined parameter entity reference within
    a markup declaration in the internal DTD subset, violating
    the PEs in Internal Subset WFC.
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-094'])
		ifTrue:[^nil].

	self assert: [self runTest: 'xmltest/valid/sa/094.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa095
	"
    Basically an output test, this requires extra whitespace
    to be normalized into a single space character in an
    attribute of type NMTOKENS.
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-095'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/095.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/095.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-095')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa096
	"
    Test demonstrates that extra whitespace is normalized into a single space character in an attribute of type NMTOKENS. 
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-096'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/096.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/096.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-096')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa097
	"
    Basically an output test, this tests whether an externally
    defined attribute declaration (with a default) takes proper
    precedence over a subsequent internal declaration.
	 See XML Spec. 1.0 section: 3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-097'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/097.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/097.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-097')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa098
	"
    Test demonstrates that extra whitespace within a processing instruction is converted into a single space character.
	 See XML Spec. 1.0 section: 2.6 2.10 [16]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-098'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/098.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/098.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-098')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa099
	"
    Test demonstrates the name of the encoding can be composed of lowercase characters. 
	 See XML Spec. 1.0 section: 4.3.3 [81]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-099'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/099.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/099.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-099')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa100
	"
    Makes sure that PUBLIC identifiers may have some strange
    characters.  NOTE:  The XML editors have said that the XML
    specification errata will specify that parameter entity expansion
    does not occur in PUBLIC identifiers, so that the '%' character
    will not flag a malformed parameter entity reference.
	 See XML Spec. 1.0 section: 2.3 [12]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-100'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/100.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/100.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-100')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa101
	"
    This tests whether entity expansion is (incorrectly) done
    while processing entity declarations; if it is, the entity
    value literal will terminate prematurely.
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-101'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/101.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/101.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-101')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa102
	"
    Test demonstrates that a CDATA attribute can pass a double quote as its value. 
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-102'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/102.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/102.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-102')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa103
	"
    Test demonstrates that an attribute can pass a less than sign as its value. 
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-103'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/103.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/103.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-103')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa104
	"
    Test demonstrates that extra whitespace within an Attribute of a Start-tag is normalized to a single space character. 
	 See XML Spec. 1.0 section: 3.1 [40]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-104'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/104.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/104.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-104')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa105
	"
    Basically an output test, this requires a CDATA attribute
    with a tab character to be passed through as one space.
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-105'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/105.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/105.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-105')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa106
	"
    Basically an output test, this requires a CDATA attribute
    with a newline character to be passed through as one space.
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-106'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/106.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/106.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-106')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa107
	"
    Basically an output test, this requires a CDATA attribute
    with a return character to be passed through as one space.
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-107'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/107.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/107.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-107')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa108
	"
    This tests normalization of end-of-line characters (CRLF)
    within entities to LF, primarily as an output test. 
	 See XML Spec. 1.0 section: 2.11, 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-108'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/108.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/108.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-108')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa109
	"
    Test demonstrates that an attribute can have a null value. 
	 See XML Spec. 1.0 section: 2.3 3.1 [10][40][41]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-109'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/109.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/109.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-109')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa110
	"
    Basically an output test, this requires that a CDATA
    attribute with a CRLF be normalized to one space.
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-110'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/110.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/110.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-110')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa111
	"
    Character references expanding to spaces doesn't affect
    treatment of attributes. 
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-111'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/111.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/111.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-111')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa112
	"
    Test demonstrates shows the use of content particles within the element content. 
	 See XML Spec. 1.0 section: 3.2.1 [48][49]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-112'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/112.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/112.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-112')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa113
	"
     Test demonstrates that it is not an error to have attributes declared for an element not itself declared.
	 See XML Spec. 1.0 section: 3.3 [52][53]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-113'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/113.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/113.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-113')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa114
	"
    Test demonstrates that all text within a valid CDATA section is considered text and not recognized as markup. 
	 See XML Spec. 1.0 section: 2.7 [20]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-114'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/114.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/114.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-114')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa115
	"
    Test demonstrates that an entity reference is processed by recursively processing the replacement text of the entity. 
	 See XML Spec. 1.0 section: 3.3.3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-115'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/115.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/115.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-115')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa116
	"
    Test demonstrates that a line break within CDATA will be normalized. 
	 See XML Spec. 1.0 section: 2.11"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-116'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/116.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/116.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-116')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa117
	"
    Test demonstrates that entity expansion is done while processing entity declarations.  
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-117'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/117.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/117.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-117')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa118
	"
    Test demonstrates that entity expansion is done while processing entity declarations. 
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-118'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/118.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/118.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-118')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsClark methodsFor: 'clark valid' stamp: ''!
testclarkvalidsa119
	"
    Comments may contain any legal XML characters;
    only the string  --  is disallowed.
	 See XML Spec. 1.0 section: 2.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'valid-sa-119'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'xmltest/valid/sa/out/119.xml')  contentsOfEntireFile.

	[result := self runTest: 'xmltest/valid/sa/119.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'valid-sa-119')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

XMLParserTests subclass: #XMLParserTestsOasis
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-Testing'!

!XMLParserTestsOasis commentStamp: '<historical>' prior: 0!
'Class Author: Roger Whitney whitney@cs.sdsu.edu
Version 2.0
April 22, 2000

XMLParserTestsOasis uses XML tests by James Clark, Sun, and OASIS. These tests are distributed as test suite by OASIS at: 
http://www.oasis-open.org/committees/xmltest/xmlconf-19990712.zip This link can be found on the page:
http://www.oasis-open.org/committees/xmltest/testsuite.htm. 

To run the test suite you must:
	Install the OASIS test suite on your hard drive
	Edit the class method baseTestDirectory to include the full path of the directory containing the OASIS test suite.
	install Sunit.
	Run the tests the standard way: TestRunner open

The VWXMPParser does not pass all tests.  OX''s release 1.2 of Cincom''s XML parser fails about 40 tests out of about 800. This classs is configured to allow you to turn some of the tests off. The class method allTestsToSkip returns an OrderedCollection of tests that can be skiped. The tests are identified using the test ID given in the files oasis/oasis.xml, xmltest/xmltest.xml, sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml which located in the OASIS test suite. The class method skipKnownBadTests determines if the tests are skipped. The class method shouldConvertCR: determines if a test should convert the cr in the Cincom''s parsers output to lf. 

The test methods in this class are generated by class methods from files in the OASIS test suite which catalog the tests (oasis/oasis.xml, xmltest/xmltest.xml, sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml) If you wish to generate the test methods, you must edit the files sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml. They need a top-level tag to enclose the entire file. It does not matter what the tag is.

Reasons the Parser fails tests

carriage return(cr) vs line feed(lf)
	The XML spec requires all carriage returns and cr-lf pairs to be converted to lf. 
	Smalltalk strings use cr, as does the parser.

Unicode characters 
	The parser fails all/nearly all test with unicode characters. The problem is in the tests. The tests
	are not reading the answer files using UFT-8 format.

Accepts attributes with out space between them

Unicode characters with large numerical value throws an exception when stored in a stream in parser

Parser does not check for incomplete uri's
Parser does not include NOTATION elements in its tree structure
Parser does not check for valid language identification
Parser does not check for validity constraints to make a document standalone
Parser does not check name of the top level element
Parser does not check for encoding declaration in Text declarations
!

!XMLParserTestsOasis class methodsFor: 'tests to skip' stamp: 'mir 11/23/2007 19:06'!
allTestsToSkip
	^#("invalid indexing caused by large unicode character being put into a stream"
		'o-p66pass1' 

		"does not reject uri fragment"
		 'o-p11pass1' )! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop01fail1
	"
     S cannot occur before the prolog
    
	 See XML Spec. 1.0 section: 2.1 [1]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p01fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p01fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop01fail2
	"
     comments cannot occur before the prolog
    
	 See XML Spec. 1.0 section: 2.1 [1]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p01fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p01fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop01fail3
	"
     only one document element
    
	 See XML Spec. 1.0 section: 2.1 [1]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p01fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p01fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop01fail4
	"
     document element must be complete.
    
	 See XML Spec. 1.0 section: 2.1 [1]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p01fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p01fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop01pass1
	"
     no prolog
    
	 See XML Spec. 1.0 section: 2.1 [1]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p01pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p01pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop01pass3
	"
     Misc items after the document
    
	 See XML Spec. 1.0 section: 2.1 [1]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p01pass3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p01pass3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail1
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail10
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail10'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail10.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail11
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail11'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail11.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail12
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail12'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail12.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail13
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail13'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail13.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail14
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail14'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail14.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail15
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail15'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail15.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail16
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail16'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail16.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail17
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail17'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail17.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail18
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail18'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail18.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail19
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail19'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail19.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail2
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail20
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail20'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail20.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail21
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail21'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail21.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail22
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail22'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail22.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail23
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail23'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail23.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail24
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail24'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail24.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail25
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail25'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail25.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail26
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail26'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail26.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail27
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail27'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail27.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail28
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail28'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail28.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail29
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail29'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail29.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail3
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail30
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail30'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail30.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail31
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail31'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail31.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail4
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail5
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail6
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail6'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail6.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail7
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail7'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail7.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail8
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail8'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail8.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop02fail9
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.2 [2]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p02fail9'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p02fail9.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail1
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail10
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail10'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail10.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail11
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail11'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail11.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail12
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail12'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail12.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail13
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail13'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail13.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail14
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail14'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail14.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail15
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail15'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail15.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail16
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail16'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail16.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail17
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail17'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail17.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail18
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail18'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail18.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail19
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail19'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail19.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail2
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail20
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail20'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail20.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail21
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail21'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail21.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail22
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail22'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail22.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail23
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail23'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail23.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail24
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail24'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail24.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail25
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail25'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail25.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail26
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail26'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail26.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail27
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail27'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail27.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail28
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail28'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail28.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail29
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail29'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail29.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail3
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail4
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail5
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail7
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail7'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail7.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail8
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail8'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail8.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop03fail9
	"
    Use of illegal character within XML document.     
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03fail9'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03fail9.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop03pass1
	"
     all valid S characters
    
	 See XML Spec. 1.0 section: 2.3 [3]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p03pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p03pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop04fail1
	"
    Name contains invalid character.    
	 See XML Spec. 1.0 section: 2.3 [4]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p04fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p04fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop04fail2
	"
    Name contains invalid character.    
	 See XML Spec. 1.0 section: 2.3 [4]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p04fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p04fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop04fail3
	"
    Name contains invalid character.    
	 See XML Spec. 1.0 section: 2.3 [4]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p04fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p04fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop04pass1
	"
     names with all valid ASCII characters, and one from each
              other class in NameChar
    
	 See XML Spec. 1.0 section: 2.3 [4]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p04pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p04pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop05fail1
	"
     a Name cannot start with a digit
    
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p05fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p05fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop05fail2
	"
     a Name cannot start with a '.'
    
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p05fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p05fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop05fail3
	"
     a Name cannot start with a  - 
    
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p05fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p05fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop05fail4
	"
     a Name cannot start with a CombiningChar
    
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p05fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p05fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop05fail5
	"
     a Name cannot start with an Extender
    
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p05fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p05fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop05pass1
	"
     various valid Name constructions
    
	 See XML Spec. 1.0 section: 2.3 [5]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p05pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p05pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop06fail1
	"
     Requires at least one name.
    
	 See XML Spec. 1.0 section: 2.3 [6]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p06fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p06fail1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop08fail1
	"
     at least one Nmtoken is required.
    
	 See XML Spec. 1.0 section: 2.3 [8]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p08fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p08fail1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop08fail2
	"
     an invalid Nmtoken character.
    
	 See XML Spec. 1.0 section: 2.3 [8]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p08fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p08fail2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop09fail1
	"
     EntityValue excludes '%'
    
	 See XML Spec. 1.0 section: 2.3 [9]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p09fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p09fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop09fail2
	"
     EntityValue excludes '&'
    
	 See XML Spec. 1.0 section: 2.3 [9]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p09fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p09fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop09fail3
	"
     incomplete character reference
    
	 See XML Spec. 1.0 section: 2.3 [9]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p09fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p09fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop09fail4
	"
     quote types must match
    
	 See XML Spec. 1.0 section: 2.3 [9]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p09fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p09fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop09fail5
	"
     quote types must match
    
	 See XML Spec. 1.0 section: 2.3 [9]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p09fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p09fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop10fail1
	"
     attribute values exclude '<'
    
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p10fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p10fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop10fail2
	"
     attribute values exclude '&'
    
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p10fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p10fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop10fail3
	"
     quote types must match
    
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p10fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p10fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop10pass1
	"
     valid attribute values
    
	 See XML Spec. 1.0 section: 2.3 [10]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p10pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p10pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop11fail1
	"
     quote types must match
    
	 See XML Spec. 1.0 section: 2.3 [11]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p11fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p11fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop11fail2
	"
     cannot contain delimiting quotes
    
	 See XML Spec. 1.0 section: 2.3 [11]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p11fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p11fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis error' stamp: ''!
testoasisop11pass1
	"
     system literals may not contain
    URI fragments
    
	 See XML Spec. 1.0 section: 2.3, 4.2.2 [11]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p11pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p11pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop12fail1
	"
     ' ' excluded
    
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p12fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p12fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop12fail2
	"
     '\' excluded
    
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p12fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p12fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop12fail3
	"
     entity references excluded
    
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p12fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p12fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop12fail4
	"
     '>' excluded
    
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p12fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p12fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop12fail5
	"
     '<' excluded
    
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p12fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p12fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop12fail6
	"
     built-in entity refs excluded
    
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p12fail6'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p12fail6.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop12fail7
	"
         
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p12fail7'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p12fail7.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop14fail1
	"
     '<' excluded
    
	 See XML Spec. 1.0 section: 2.4 [14]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p14fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p14fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop14fail2
	"
     '&' excluded
    
	 See XML Spec. 1.0 section: 2.4 [14]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p14fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p14fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop14fail3
	"
      ]]>  excluded
    
	 See XML Spec. 1.0 section: 2.4 [14]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p14fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p14fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop14pass1
	"
     valid CharData
    
	 See XML Spec. 1.0 section: 2.4 [14]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p14pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p14pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop15fail1
	"
     comments can't end in '-'
    
	 See XML Spec. 1.0 section: 2.5 [15]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p15fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p15fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop15fail2
	"
     one comment per comment (contrasted with SGML)
    
	 See XML Spec. 1.0 section: 2.5 [15]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p15fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p15fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop15fail3
	"
     can't include 2 or more adjacent '-'s
    
	 See XML Spec. 1.0 section: 2.5 [15]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p15fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p15fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop15pass1
	"
     valid comments
    
	 See XML Spec. 1.0 section: 2.5 [15]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p15pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p15pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop16fail1
	"
      xml  is an invalid PITarget
    
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p16fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p16fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop16fail2
	"
     a PITarget must be present
    
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p16fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p16fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop16fail3
	"
     S after PITarget is required
    
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p16fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p16fail3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop16pass1
	"
    Valid form of Processing Instruction. Shows that whitespace character data is valid before end of processing instruction.     
	 See XML Spec. 1.0 section: 2.6 [16] [17]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p16pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p16pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop16pass2
	"
    Valid form of Processing Instruction. Shows that whitespace character data is valid before end of processing instruction.     
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p16pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p16pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop16pass3
	"
    Valid form of Processing Instruction. Shows that whitespace character data is valid before end of processing instruction.     
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p16pass3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p16pass3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop18fail1
	"
     no space before  CDATA 
    
	 See XML Spec. 1.0 section: 2.7 [18]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p18fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p18fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop18fail2
	"
     no space after  CDATA 
    
	 See XML Spec. 1.0 section: 2.7 [18]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p18fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p18fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop18fail3
	"
     CDSect's can't nest
    
	 See XML Spec. 1.0 section: 2.7 [18]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p18fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p18fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop18pass1
	"
     valid CDSect's.  Note that a CDStart in a CDSect is not
              recognized as such
    
	 See XML Spec. 1.0 section: 2.7 [18]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p18pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p18pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop22fail1
	"
     prolog must start with XML decl
    
	 See XML Spec. 1.0 section: 2.8 [22]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p22fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p22fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop22fail2
	"
     prolog must start with XML decl
    
	 See XML Spec. 1.0 section: 2.8 [22]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p22fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p22fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop22pass1
	"
     prolog can be empty
    
	 See XML Spec. 1.0 section: 2.8 [22]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p22pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p22pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop22pass2
	"
     XML declaration only
    
	 See XML Spec. 1.0 section: 2.8 [22]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p22pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p22pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop22pass3
	"
     XML decl and Misc
    
	 See XML Spec. 1.0 section: 2.8 [22]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p22pass3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p22pass3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop23fail1
	"
      xml  must be lower-case
    
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop23fail2
	"
     VersionInfo must be supplied
    
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop23fail3
	"
     VersionInfo must come first
    
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop23fail4
	"
     SDDecl must come last
    
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop23fail5
	"
     no SGML-type PIs
    
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop23pass1
	"
    Test shows a valid XML declaration along with version info.     
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop23pass2
	"
    Test shows a valid XML declaration along with encoding declaration.     
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop23pass3
	"
    Test shows a valid XML declaration along with Standalone Document Declaration.     
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23pass3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23pass3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop23pass4
	"
    Test shows a valid XML declaration, encoding declarationand Standalone Document Declaration.     
	 See XML Spec. 1.0 section: 2.8 [23]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p23pass4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p23pass4.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop24fail1
	"
     quote types must match
    
	 See XML Spec. 1.0 section: 2.8 [24]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p24fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p24fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop24fail2
	"
     quote types must match
    
	 See XML Spec. 1.0 section: 2.8 [24]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p24fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p24fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop24pass1
	"
    Test shows a prolog that has the VersionInfo delimited by double quotes.     
	 See XML Spec. 1.0 section: 2.8 [24]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p24pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p24pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop24pass2
	"
    Test shows a prolog that has the VersionInfo delimited by single quotes.     
	 See XML Spec. 1.0 section: 2.8 [24]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p24pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p24pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop24pass3
	"
    Test shows whitespace is allowed in prolog before version info.     
	 See XML Spec. 1.0 section: 2.8 [24]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p24pass3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p24pass3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop24pass4
	"
    Test shows whitespace is allowed in prolog on both sides of equal sign.     
	 See XML Spec. 1.0 section: 2.8 [24]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p24pass4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p24pass4.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop25fail1
	"
    Comment is illegal in VersionInfo.     
	 See XML Spec. 1.0 section: 2.8 [25]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p25fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p25fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop25pass1
	"
    Test shows whitespace is NOT necessary before or after equal sign of versioninfo.     
	 See XML Spec. 1.0 section: 2.8 [25]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p25pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p25pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop25pass2
	"
    Test shows whitespace can be used on both sides of equal sign of versioninfo.     
	 See XML Spec. 1.0 section: 2.8 [25]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p25pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p25pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop26fail1
	"
    Illegal character in VersionNum.     
	 See XML Spec. 1.0 section: 2.8 [26]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p26fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p26fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop26fail2
	"
    Illegal character in VersionNum.     
	 See XML Spec. 1.0 section: 2.8 [26]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p26fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p26fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop26pass1
	"
     The valid version number.  We cannot test others because
              a 1.0 processor is allowed to fail them.
    
	 See XML Spec. 1.0 section: 2.8 [26]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p26pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p26pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop27fail1
	"
     References aren't allowed in Misc,
    even if they would resolve to valid Misc.
    
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p27fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p27fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop27pass1
	"
    Comments are valid as the Misc part of the prolog.    
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p27pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p27pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop27pass2
	"
    Processing Instructions are valid as the Misc part of the prolog.     
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p27pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p27pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop27pass3
	"
    Whitespace is valid as the Misc part of the prolog.     
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p27pass3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p27pass3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop27pass4
	"
    A combination of comments, whitespaces and processing instructions are valid as the Misc part of the prolog.     
	 See XML Spec. 1.0 section: 2.8 [27]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p27pass4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p27pass4.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop28fail1
	"
     only declarations in DTD.
    
	 See XML Spec. 1.0 section: 2.8 [28]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p28fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p28fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop29fail1
	"
     A processor must not pass unknown declaration types.
    
	 See XML Spec. 1.0 section: 2.8 [29]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p29fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p29fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop30fail1
	"
     An XML declaration is not the same as a TextDecl
    
	 See XML Spec. 1.0 section: 2.8 [30]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p30fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p30fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop31fail1
	"
     external subset excludes doctypedecl
    
	 See XML Spec. 1.0 section: 2.8 [31]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p31fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p31fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop32fail1
	"
     quote types must match
    
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p32fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p32fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop32fail2
	"
     quote types must match
    
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p32fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p32fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop32fail3
	"
     initial S is required
    
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p32fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p32fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop32fail4
	"
     quotes are required
    
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p32fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p32fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop32fail5
	"
     yes or no must be lower case
    
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p32fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p32fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop32pass1
	"
    Double quotes can be used as delimeters for the value of a Standalone Document Declaration.     
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p32pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p32pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop32pass2
	"
    Single quotes can be used as delimeters for the value of a Standalone Document Declaration.     
	 See XML Spec. 1.0 section: 2.9 [32]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p32pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p32pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop39fail1
	"
     start-tag requires end-tag
    
	 See XML Spec. 1.0 section: 3 [39]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p39fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p39fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop39fail2
	"
     end-tag requires start-tag
    
	 See XML Spec. 1.0 section: 3 [39]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p39fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p39fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop39fail3
	"
    XML documents contain one or more elements
	 See XML Spec. 1.0 section: 3 [39]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p39fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p39fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop39fail4
	"
         
	 See XML Spec. 1.0 section: 3 [39]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p39fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p39fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop39fail5
	"
         
	 See XML Spec. 1.0 section: 3 [39]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p39fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p39fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop39pass1
	"
    Empty element tag may be used for any element which has no content.     
	 See XML Spec. 1.0 section: 3 3.1 [39] [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p39pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p39pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop39pass2
	"
    Character data is valid element content.     
	 See XML Spec. 1.0 section: 3 3.1 [39] [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p39pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p39pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop40fail1
	"
     S is required between attributes
    
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p40fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p40fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop40fail2
	"
     tags start with names, not nmtokens
    
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p40fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p40fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop40fail3
	"
     tags start with names, not nmtokens
    
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p40fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p40fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop40fail4
	"
     no space before name
    
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p40fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p40fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop40pass1
	"
    Elements content can be empty.     
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p40pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p40pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop40pass2
	"
    Whitespace is valid within a Start-tag.     
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p40pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p40pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop40pass3
	"
    Attributes are valid within a Start-tag.    
	 See XML Spec. 1.0 section: 3.1 [40] [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p40pass3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p40pass3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop40pass4
	"
    Whitespace and Multiple Attributes are valid within a Start-tag.     
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p40pass4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p40pass4.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop41fail1
	"
     quotes are required (contrast with SGML)
    
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p41fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p41fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop41fail2
	"
     attribute name is required (contrast with SGML)
    
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p41fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p41fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop41fail3
	"
     Eq required
    
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p41fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p41fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop41pass1
	"
    Attributes are valid within a Start-tag.     
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p41pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p41pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop41pass2
	"
    Whitespace is valid within a Start-tags Attribute.    
	 See XML Spec. 1.0 section: 3.1 [41]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p41pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p41pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop42fail1
	"
     no space before name
    
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p42fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p42fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop42fail2
	"
     cannot end with  /> 
    
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p42fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p42fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop42fail3
	"
     no NET (contrast with SGML)
    
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p42fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p42fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop42pass1
	"
    Test shows proper syntax for an End-tag.    
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p42pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p42pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop42pass2
	"
    Whitespace is valid after name in End-tag.     
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p42pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p42pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop43fail1
	"
     no non-comment declarations
    
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p43fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p43fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop43fail2
	"
     no conditional sections
    
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p43fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p43fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop43fail3
	"
     no conditional sections
    
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p43fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p43fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop44fail1
	"
    Illegal space before Empty element tag.    
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop44fail2
	"
    Illegal space after Empty element tag.    
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop44fail3
	"
    Illegal comment in Empty element tag.    
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop44fail4
	"
    Whitespace required between attributes.    
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop44fail5
	"
    Duplicate attribute name is illegal.    
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop44pass1
	"
    Valid display of an Empty Element Tag.    
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop44pass2
	"
    Empty Element Tags can contain an Attribute.    
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44pass2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44pass2.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop44pass3
	"
    Whitespace is valid in an Empty Element Tag following the end of the attribute value.     
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44pass3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44pass3.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop44pass4
	"
    Whitespace is valid after the name in an Empty Element Tag.     
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44pass4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44pass4.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop44pass5
	"
    Whitespace and Multiple Attributes are valid in an Empty Element Tag.    
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p44pass5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p44pass5.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop45fail1
	"
     ELEMENT must be upper case.
    
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p45fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p45fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop45fail2
	"
     S before contentspec is required.
    
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p45fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p45fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop45fail3
	"
     only one content spec
    
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p45fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p45fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop45fail4
	"
     no comments in declarations (contrast with SGML)
    
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p45fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p45fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop46fail1
	"
     no parens on declared content
    
	 See XML Spec. 1.0 section: 3.2 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p46fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p46fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop46fail2
	"
     no inclusions (contrast with SGML)
    
	 See XML Spec. 1.0 section: 3.2 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p46fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p46fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop46fail3
	"
     no exclusions (contrast with SGML)
    
	 See XML Spec. 1.0 section: 3.2 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p46fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p46fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop46fail4
	"
     no space before occurrence
    
	 See XML Spec. 1.0 section: 3.2 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p46fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p46fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop46fail5
	"
     single group
    
	 See XML Spec. 1.0 section: 3.2 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p46fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p46fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop46fail6
	"
     can't be both declared and modeled
    
	 See XML Spec. 1.0 section: 3.2 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p46fail6'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p46fail6.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop47fail1
	"
    Invalid operator '|' must match previous operator ','
	 See XML Spec. 1.0 section: 3.2.1 [47]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p47fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p47fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop47fail2
	"
    Illegal character '-' in Element-content model     
	 See XML Spec. 1.0 section: 3.2.1 [47]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p47fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p47fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop47fail3
	"
    Optional character must follow a name or list     
	 See XML Spec. 1.0 section: 3.2.1 [47]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p47fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p47fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop47fail4
	"
    Illegal space before optional character
	 See XML Spec. 1.0 section: 3.2.1 [47]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p47fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p47fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop48fail1
	"
    Illegal space before optional character    
	 See XML Spec. 1.0 section: 3.2.1 [48]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p48fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p48fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop48fail2
	"
    Illegal space before optional character     
	 See XML Spec. 1.0 section: 3.2.1 [48]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p48fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p48fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop49fail1
	"
    connectors must match     
	 See XML Spec. 1.0 section: 3.2.1 [49]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p49fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p49fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop50fail1
	"
    connectors must match     
	 See XML Spec. 1.0 section: 3.2.1 [50]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p50fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p50fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop51fail1
	"
     occurrence on #PCDATA group must be *
    
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p51fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p51fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop51fail2
	"
     occurrence on #PCDATA group must be *
    
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p51fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p51fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop51fail3
	"
     #PCDATA must come first
    
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p51fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p51fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop51fail4
	"
     occurrence on #PCDATA group must be *
    
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p51fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p51fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop51fail5
	"
     only '|' connectors
    
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p51fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p51fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop51fail6
	"
    Only '|' connectors and occurrence on #PCDATA group must be *     
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p51fail6'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p51fail6.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop51fail7
	"
     no nested groups
    
	 See XML Spec. 1.0 section: 3.2.2 [51]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p51fail7'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p51fail7.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop52fail1
	"
     A name is required
    
	 See XML Spec. 1.0 section: 3.3 [52]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p52fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p52fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop52fail2
	"
     A name is required
    
	 See XML Spec. 1.0 section: 3.3 [52]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p52fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p52fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop53fail1
	"
     S is required before default
    
	 See XML Spec. 1.0 section: 3.3 [53]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p53fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p53fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop53fail2
	"
     S is required before type
    
	 See XML Spec. 1.0 section: 3.3 [53]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p53fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p53fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop53fail3
	"
     type is required
    
	 See XML Spec. 1.0 section: 3.3 [53]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p53fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p53fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop53fail4
	"
     default is required
    
	 See XML Spec. 1.0 section: 3.3 [53]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p53fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p53fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop53fail5
	"
     name is requried
    
	 See XML Spec. 1.0 section: 3.3 [53]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p53fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p53fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop54fail1
	"
     don't pass unknown attribute types
    
	 See XML Spec. 1.0 section: 3.3.1 [54]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p54fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p54fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop55fail1
	"
     must be upper case
    
	 See XML Spec. 1.0 section: 3.3.1 [55]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p55fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p55fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop56fail1
	"
     no IDS type
    
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p56fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p56fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop56fail2
	"
     no NUMBER type
    
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p56fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p56fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop56fail3
	"
     no NAME type
    
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p56fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p56fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop56fail4
	"
     no ENTITYS type
- types must be upper case
    
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p56fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p56fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop56fail5
	"
    types must be upper case     
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p56fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p56fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop57fail1
	"
     no keyword for NMTOKEN enumeration
    
	 See XML Spec. 1.0 section: 3.3.1 [57]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p57fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p57fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop58fail1
	"
     at least one value required
    
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p58fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p58fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop58fail2
	"
     separator must be '|'
    
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p58fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p58fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop58fail3
	"
     notations are NAMEs, not NMTOKENs -- note:
    Leaving the invalid
          notation undeclared would cause a validating parser to fail without
          checking the name syntax, so the notation is declared with an
          invalid name.  A parser that reports error positions should report
          an error at the AttlistDecl on line 6, before reaching the notation
          declaration.
    
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p58fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p58fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop58fail4
	"
     NOTATION must be upper case
    
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p58fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p58fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop58fail5
	"
     S after keyword is required
    
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p58fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p58fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop58fail6
	"
     parentheses are require
    
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p58fail6'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p58fail6.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop58fail7
	"
     values are unquoted
    
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p58fail7'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p58fail7.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop58fail8
	"
     values are unquoted
    
	 See XML Spec. 1.0 section: 3.3.1 [58]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p58fail8'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p58fail8.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop59fail1
	"
     at least one required
    
	 See XML Spec. 1.0 section: 3.3.1 [59]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p59fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p59fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop59fail2
	"
     separator must be  , 
    
	 See XML Spec. 1.0 section: 3.3.1 [59]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p59fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p59fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop59fail3
	"
     values are unquoted
    
	 See XML Spec. 1.0 section: 3.3.1 [59]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p59fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p59fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop60fail1
	"
     keywords must be upper case
    
	 See XML Spec. 1.0 section: 3.3.2 [60]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p60fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p60fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop60fail2
	"
     S is required after #FIXED
    
	 See XML Spec. 1.0 section: 3.3.2 [60]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p60fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p60fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop60fail3
	"
     only #FIXED has both keyword and value
    
	 See XML Spec. 1.0 section: 3.3.2 [60]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p60fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p60fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop60fail4
	"
     #FIXED required value
    
	 See XML Spec. 1.0 section: 3.3.2 [60]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p60fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p60fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop60fail5
	"
     only one default type
    
	 See XML Spec. 1.0 section: 3.3.2 [60]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p60fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p60fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop61fail1
	"
     no other types, including TEMP, which is valid in SGML
    
	 See XML Spec. 1.0 section: 3.4 [61]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p61fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p61fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop62fail1
	"
     INCLUDE must be upper case
    
	 See XML Spec. 1.0 section: 3.4 [62]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p62fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p62fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop62fail2
	"
     no spaces in terminating delimiter
    
	 See XML Spec. 1.0 section: 3.4 [62]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p62fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p62fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop63fail1
	"
     IGNORE must be upper case
    
	 See XML Spec. 1.0 section: 3.4 [63]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p63fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p63fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop63fail2
	"
     delimiters must be balanced
    
	 See XML Spec. 1.0 section: 3.4 [63]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p63fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p63fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop64fail1
	"
     section delimiters must balance
    
	 See XML Spec. 1.0 section: 3.4 [64]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p64fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p64fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop64fail2
	"
     section delimiters must balance
    
	 See XML Spec. 1.0 section: 3.4 [64]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p64fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p64fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop66fail1
	"
     terminating ';' is required
    
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p66fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p66fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop66fail2
	"
     no S after '&#'
    
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p66fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p66fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop66fail3
	"
     no hex digits in numeric reference
    
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p66fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p66fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop66fail4
	"
     only hex digits in hex references
    
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p66fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p66fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop66fail5
	"
     no references to non-characters
    
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p66fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p66fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop66fail6
	"
     no references to non-characters
    
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p66fail6'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p66fail6.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop66pass1
	"
     valid character references
    
	 See XML Spec. 1.0 section: 4.1 [66]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p66pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p66pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop68fail1
	"
     terminating ';' is required
    
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p68fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p68fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop68fail2
	"
     no S after '&'
    
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p68fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p68fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop68fail3
	"
     no S before ';'
    
	 See XML Spec. 1.0 section: 4.1 [68]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p68fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p68fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop69fail1
	"
     terminating ';' is required
    
	 See XML Spec. 1.0 section: 4.1 [69]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p69fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p69fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop69fail2
	"
     no S after '%'
    
	 See XML Spec. 1.0 section: 4.1 [69]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p69fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p69fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop69fail3
	"
     no S before ';'
    
	 See XML Spec. 1.0 section: 4.1 [69]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p69fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p69fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop70fail1
	"
     This is neither
    
	 See XML Spec. 1.0 section: 4.2 [70]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p70fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p70fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop71fail1
	"
     S is required before EntityDef
    
	 See XML Spec. 1.0 section: 4.2 [71]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p71fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p71fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop71fail2
	"
     Entity name is a Name, not an NMToken
    
	 See XML Spec. 1.0 section: 4.2 [71]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p71fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p71fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop71fail3
	"
     no S after  <!! 
    
	 See XML Spec. 1.0 section: 4.2 [71]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p71fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p71fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop71fail4
	"
     S is required after  <!!ENTITY 
    
	 See XML Spec. 1.0 section: 4.2 [71]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p71fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p71fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop72fail1
	"
     S is required after  <!!ENTITY 
    
	 See XML Spec. 1.0 section: 4.2 [72]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p72fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p72fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop72fail2
	"
     S is required after '%'
    
	 See XML Spec. 1.0 section: 4.2 [72]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p72fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p72fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop72fail3
	"
     S is required after name
    
	 See XML Spec. 1.0 section: 4.2 [72]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p72fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p72fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop72fail4
	"
     Entity name is a name, not an NMToken
    
	 See XML Spec. 1.0 section: 4.2 [72]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p72fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p72fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop73fail1
	"
     No typed replacement text
    
	 See XML Spec. 1.0 section: 4.2 [73]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p73fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p73fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop73fail2
	"
     Only one replacement value
    
	 See XML Spec. 1.0 section: 4.2 [73]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p73fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p73fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop73fail3
	"
     No NDataDecl on replacement text
    
	 See XML Spec. 1.0 section: 4.2 [73]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p73fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p73fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop73fail4
	"
     Value is required
    
	 See XML Spec. 1.0 section: 4.2 [73]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p73fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p73fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop73fail5
	"
     No NDataDecl without value
    
	 See XML Spec. 1.0 section: 4.2 [73]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p73fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p73fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop74fail1
	"
     no NDataDecls on parameter entities
    
	 See XML Spec. 1.0 section: 4.2 [74]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p74fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p74fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop74fail2
	"
     value is required
    
	 See XML Spec. 1.0 section: 4.2 [74]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p74fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p74fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop74fail3
	"
     only one value
    
	 See XML Spec. 1.0 section: 4.2 [74]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p74fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p74fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop74pass1
	"
     PEDef is either an entity value or an external id
    
	 See XML Spec. 1.0 section: 4.2 [74]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p74pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p74pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop75fail1
	"
     S required after  PUBLIC 
    
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p75fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p75fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop75fail2
	"
     S required after  SYSTEM 
    
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p75fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p75fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop75fail3
	"
     S required between literals
    
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p75fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p75fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop75fail4
	"
      SYSTEM  implies only one literal
    
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p75fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p75fail4.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop75fail5
	"
     only one keyword
    
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p75fail5'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p75fail5.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop75fail6
	"
      PUBLIC  requires two literals (contrast with SGML)
    
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p75fail6'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p75fail6.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis invalid' stamp: ''!
testoasisop75pass1
	"
     valid external identifiers
    
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p75pass1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p75pass1.xml']
		raises: self exceptionSet! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop76fail1
	"
     S is required before  NDATA 
    
	 See XML Spec. 1.0 section: 4.2.2 [76]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p76fail1'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p76fail1.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop76fail2
	"
      NDATA  is upper-case
    
	 See XML Spec. 1.0 section: 4.2.2 [76]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p76fail2'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p76fail2.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop76fail3
	"
     notation name is required
    
	 See XML Spec. 1.0 section: 4.2.2 [76]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p76fail3'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p76fail3.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsOasis methodsFor: 'oasis not wf' stamp: ''!
testoasisop76fail4
	"
     notation names are Names
    
	 See XML Spec. 1.0 section: 4.2.2 [76]"

	(self class shouldSkipTests and: [testsToSkip includes: 'o-p76fail4'])
		ifTrue:[^nil].

	self assert: [self runTest: 'oasis/p76fail4.xml' ]
		raises: self exceptionSet2! !

XMLParserTests subclass: #XMLParserTestsSun
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-Testing'!

!XMLParserTestsSun commentStamp: '<historical>' prior: 0!
'Class Author: Roger Whitney whitney@cs.sdsu.edu
Version 2.0
April 22, 2000

XMLParserTestsSun uses XML tests by James Clark, Sun, and OASIS. These tests are distributed as test suite by OASIS at: 
http://www.oasis-open.org/committees/xmltest/xmlconf-19990712.zip This link can be found on the page:
http://www.oasis-open.org/committees/xmltest/testsuite.htm. 

To run the test suite you must:
	Install the OASIS test suite on your hard drive
	Edit the class method baseTestDirectory to include the full path of the directory containing the OASIS test suite.
	install Sunit.
	Run the tests the standard way: TestRunner open

The VWXMPParser does not pass all tests.  OX''s release 1.2 of Cincom''s XML parser fails about 40 tests out of about 800. This classs is configured to allow you to turn some of the tests off. The class method allTestsToSkip returns an OrderedCollection of tests that can be skiped. The tests are identified using the test ID given in the files oasis/oasis.xml, xmltest/xmltest.xml, sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml which located in the OASIS test suite. The class method skipKnownBadTests determines if the tests are skipped. The class method shouldConvertCR: determines if a test should convert the cr in the Cincom''s parsers output to lf. 

The test methods in this class are generated by class methods from files in the OASIS test suite which catalog the tests (oasis/oasis.xml, xmltest/xmltest.xml, sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml) If you wish to generate the test methods, you must edit the files sun/valid/sun-valid.xml, sun/invalid/sun-invalid.xml, sun/not-wf/sun-not-wf.xml, sun/error/sun-error.xml. They need a top-level tag to enclose the entire file. It does not matter what the tag is.

Reasons the Parser fails tests

carriage return(cr) vs line feed(lf)
	The XML spec requires all carriage returns and cr-lf pairs to be converted to lf. 
	Smalltalk strings use cr, as does the parser.

Unicode characters 
	The parser fails all/nearly all test with unicode characters. The problem is in the tests. The tests
	are not reading the answer files using UFT-8 format.

Accepts attributes with out space between them

Unicode characters with large numerical value throws an exception when stored in a stream in parser

Parser does not check for incomplete uri's
Parser does not include NOTATION elements in its tree structure
Parser does not check for valid language identification
Parser does not check for validity constraints to make a document standalone
Parser does not check name of the top level element
Parser does not check for encoding declaration in Text declarations
!

!XMLParserTestsSun class methodsFor: 'tests to skip' stamp: 'mir 11/23/2007 19:09'!
allTestsToSkip
	"XMLParserTestsSun sunTestsToSkip size"
	"return the ID (see the XML file listing all tests) of the tests you do not want to be run"
	^#( "Cincom parser does not include NOTATION elements in its tree structure"
		'notation01' 'not-sa01' 'sa02' 'sa04' 'not-sa04' 'sa03' 'not-sa03' 'not-sa02' 'sa05'
		
		"Cincom parser does not check for valid language identification"
		'lang05' 'lang01' 'lang06' 'lang03' 'lang04' 'lang02'

		"Cincom parser does not check for validity constraints to make a document standalone"
		'inv-not-sa07' 'inv-not-sa08' 'inv-not-sa12' 'inv-not-sa09' 'inv-not-sa01' 'inv-not-sa13' 
		'inv-not-sa10' 'inv-not-sa04' 'inv-not-sa14' 'inv-not-sa11' 'inv-not-sa05' 'inv-not-sa03'
		'inv-not-sa06' 

		"Cincom parser does not complain when there are no spaces between attributes"
		'attlist11' 'attlist10' 

		"Parser does not check name of the top level element"
		'root'

		"Parser does not check for encoding declaration in Text declarations"
		'encoding07' 'dtd07'

		"cr-lf problem"
	"	'sa068'  'sa107' "

		"Parser does not check for uri fragements"
		'uri01'

		"problem with external PE"
		'pe01'

		"Character encoding problem"
		'v-pe00')! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist01
	"
    SGML's NUTOKEN is not allowed.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist02
	"
    SGML's NUTOKENS attribute type is not allowed.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist02.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist03
	"
    Comma doesn't separate enumerations, unlike in SGML.
	 See XML Spec. 1.0 section: 3.3.1 [59]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist03.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist04
	"
    SGML's NUMBER attribute type is not allowed.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist04.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist05
	"
    SGML's NUMBERS attribute type is not allowed.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist05.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist06
	"
    SGML's NAME attribute type is not allowed.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist06.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist07
	"
    SGML's NAMES attribute type is not allowed.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist07'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist07.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist08
	"
    SGML's #CURRENT is not allowed.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist08'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist08.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist09
	"
    SGML's #CONREF is not allowed.
	 See XML Spec. 1.0 section: 3.3.1 [56]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist09'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist09.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist10
	"
    Whitespace required between attributes
	 See XML Spec. 1.0 section: 3.1 [40]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist10'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist10.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunattlist11
	"
    Whitespace required between attributes
	 See XML Spec. 1.0 section: 3.1 [44]"

	(self class shouldSkipTests and: [testsToSkip includes: 'attlist11'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/attlist11.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr01
	"
    Tests the  Entity Name  VC for the ENTITY attribute type.
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr02
	"
    Tests the  Entity Name  VC for the ENTITIES attribute type.
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr02.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr03
	"
    Tests the  Notation Attributes  VC for the
    NOTATION attribute type, first clause:  value must be one
    of the ones that's declared.
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr03.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr04
	"
    Tests the  Notation Attributes  VC for the
    NOTATION attribute type, second clause:  the names in the
    declaration must all be declared.
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr04.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr05
	"
    Tests the  Name Token  VC for the NMTOKEN attribute type.
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr05.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr06
	"
    Tests the  Name Token  VC for the NMTOKENS attribute type.
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr06.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr07
	"
    Tests the  Enumeration  VC by providing
    a value which wasn't one of the choices.
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr07'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr07.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr08
	"
    Tests the  Fixed Attribute Default  VC by
    providing the wrong value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr08'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr08.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr09
	"
    Tests the  Attribute Default Legal  VC by
    providing an illegal IDREF value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr09'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr09.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr10
	"
    Tests the  Attribute Default Legal  VC by
    providing an illegal IDREFS value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr10'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr10.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr11
	"
    Tests the  Attribute Default Legal  VC by
    providing an illegal ENTITY value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr11'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr11.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr12
	"
    Tests the  Attribute Default Legal  VC by
    providing an illegal ENTITIES value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr12'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr12.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr13
	"
    Tests the  Attribute Default Legal  VC by
    providing an illegal NMTOKEN value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr13'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr13.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr14
	"
    Tests the  Attribute Default Legal  VC by
    providing an illegal NMTOKENS value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr14'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr14.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr15
	"
    Tests the  Attribute Default Legal  VC by
    providing an illegal NOTATIONS value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr15'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr15.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunattr16
	"
    Tests the  Attribute Default Legal  VC by
    providing an illegal enumeration value.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'attr16'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/attr16.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsuncond01
	"
    Only INCLUDE and IGNORE are conditional section keywords
	 See XML Spec. 1.0 section: 3.4 [61]"

	(self class shouldSkipTests and: [testsToSkip includes: 'cond01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/cond01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsuncond02
	"
    Must have keyword in conditional sections
	 See XML Spec. 1.0 section: 3.4 [61]"

	(self class shouldSkipTests and: [testsToSkip includes: 'cond02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/cond02.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsuncontent01
	"
    No whitespace before  ?  in content model
	 See XML Spec. 1.0 section: 3.2.1 [48]"

	(self class shouldSkipTests and: [testsToSkip includes: 'content01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/content01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsuncontent02
	"
    No whitespace before  *  in content model
	 See XML Spec. 1.0 section: 3.2.1 [48]"

	(self class shouldSkipTests and: [testsToSkip includes: 'content02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/content02.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsuncontent03
	"
    No whitespace before  +  in content model
	 See XML Spec. 1.0 section: 3.2.1 [48]"

	(self class shouldSkipTests and: [testsToSkip includes: 'content03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/content03.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsundecl01
	"
    External entities may not have standalone decls. 
	 See XML Spec. 1.0 section: 4.3.1 [77]"

	(self class shouldSkipTests and: [testsToSkip includes: 'decl01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/decl01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsundtd00
	"
    Tests parsing of alternative forms of text-only mixed
	content declaration.
	 See XML Spec. 1.0 section: 3.2.2 [51]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'dtd00'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/dtd00.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/dtd00.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'dtd00')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsundtd01
	"
    Comments don't get parameter entity expansion
	 See XML Spec. 1.0 section: 2.5 [15]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'dtd01'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/dtd01.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/dtd01.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'dtd01')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsundtd02
	"
    PE name immediately after  % 
	 See XML Spec. 1.0 section: 4.1 [69]"

	(self class shouldSkipTests and: [testsToSkip includes: 'dtd02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/dtd02.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsundtd03
	"
    PE name immediately followed by  ; 
	 See XML Spec. 1.0 section: 4.1 [69]"

	(self class shouldSkipTests and: [testsToSkip includes: 'dtd03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/dtd03.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsundtd04
	"
    PUBLIC literal must be quoted
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'dtd04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/dtd04.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsundtd05
	"
    SYSTEM identifier must be quoted
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'dtd05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/dtd05.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsundtd07
	"
    Text declarations (which optionally begin any external entity)
    are required to have  encoding=... . 
	 See XML Spec. 1.0 section: 4.3.1 [77]"

	(self class shouldSkipTests and: [testsToSkip includes: 'dtd07'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/dtd07.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunel01
	"
    Tests the Element Valid VC (clause 4)
    by including an undeclared child element.  
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'el01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/el01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunel02
	"
    Tests the Element Valid VC (clause 1)
    by including elements in an EMPTY content model.  
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'el02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/el02.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunel03
	"
    Tests the Element Valid VC (clause 3) by including a child element
    not permitted by a mixed content model.  
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'el03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/el03.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunel04
	"
    Tests the Unique Element Type Declaration VC. 
	 See XML Spec. 1.0 section: 3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'el04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/el04.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunel05
	"
    Tests the No Duplicate Types VC. 
	 See XML Spec. 1.0 section: 3.2.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'el05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/el05.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunel06
	"
    Tests the Element Valid VC (clause 1),
    using one of the predefined internal entities
    inside an EMPTY content model.
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'el06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/el06.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunelement
	"
    Tests clauses 1, 3, and 4 of the Element Valid
	validity constraint.
	 See XML Spec. 1.0 section: 3"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'element'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/element.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/element.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'element')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunelement00
	"
    EOF in middle of incomplete ETAG
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'element00'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/element00.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunelement01
	"
    EOF in middle of incomplete ETAG
	 See XML Spec. 1.0 section: 3.1 [42]"

	(self class shouldSkipTests and: [testsToSkip includes: 'element01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/element01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunelement02
	"
    Illegal markup (<%@ ... %>)
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'element02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/element02.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunelement03
	"
    Illegal markup (<% ... %>)
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'element03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/element03.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunelement04
	"
    Illegal markup (<!!ELEMENT ... >)
	 See XML Spec. 1.0 section: 3.1 [43]"

	(self class shouldSkipTests and: [testsToSkip includes: 'element04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/element04.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunempty
	"
    Whitespace found in CDATA sections and entity references
	works is treated like other optional whitespace
	 See XML Spec. 1.0 section: 2.4 2.7 [18]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'empty'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/empty.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/empty.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'empty')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunencoding01
	"
    Illegal character     in encoding name
	 See XML Spec. 1.0 section: 4.3.3 [81]"

	(self class shouldSkipTests and: [testsToSkip includes: 'encoding01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/encoding01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunencoding02
	"
    Illegal character  /  in encoding name
	 See XML Spec. 1.0 section: 4.3.3 [81]"

	(self class shouldSkipTests and: [testsToSkip includes: 'encoding02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/encoding02.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunencoding03
	"
    Illegal character reference in encoding name
	 See XML Spec. 1.0 section: 4.3.3 [81]"

	(self class shouldSkipTests and: [testsToSkip includes: 'encoding03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/encoding03.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunencoding04
	"
    Illegal character  :  in encoding name
	 See XML Spec. 1.0 section: 4.3.3 [81]"

	(self class shouldSkipTests and: [testsToSkip includes: 'encoding04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/encoding04.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunencoding05
	"
    Illegal character  @  in encoding name
	 See XML Spec. 1.0 section: 4.3.3 [81]"

	(self class shouldSkipTests and: [testsToSkip includes: 'encoding05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/encoding05.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunencoding06
	"
    Illegal character  +  in encoding name
	 See XML Spec. 1.0 section: 4.3.3 [81]"

	(self class shouldSkipTests and: [testsToSkip includes: 'encoding06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/encoding06.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunencoding07
	"
    Text declarations (which optionally begin any external entity)
    are required to have  encoding=... . 
	 See XML Spec. 1.0 section: 4.3.1 [77]"

	(self class shouldSkipTests and: [testsToSkip includes: 'encoding07'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/encoding07.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunext01
	"
    Tests use of external parsed entities with and without content.
	 See XML Spec. 1.0 section: 4.3.1 4.3.2 [77] [78]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'ext01'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/ext01.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/ext01.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'ext01')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunext02
	"
    Tests use of external parsed entities with different
	encodings than the base document.
	 See XML Spec. 1.0 section: 4.3.2 [78]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'ext02'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/ext02.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/ext02.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'ext02')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid01
	"
    Tests the ID (is a Name) VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid02
	"
    Tests the ID (appears once) VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id02.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid03
	"
    Tests the One ID per Element Type VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id03.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid04
	"
    Tests the ID Attribute Default VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id04.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid05
	"
    Tests the ID Attribute Default VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id05.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid06
	"
    Tests the IDREF (is a Name) VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id06.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid07
	"
    Tests the IDREFS (is a Names) VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id07'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id07.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid08
	"
    Tests the IDREF (matches an ID) VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id08'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id08.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunid09
	"
    Tests the IDREF (IDREFS matches an ID) VC
	 See XML Spec. 1.0 section: 3.3.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'id09'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/id09.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvdtd01
	"
    Tests the No Duplicate Types VC
	 See XML Spec. 1.0 section: 3.2.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-dtd01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/dtd01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvdtd02
	"
    Tests the  Notation Declared  VC by using an undeclared
    notation name.
	 See XML Spec. 1.0 section: 4.2.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-dtd02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/dtd02.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvdtd03
	"
    Tests the  Element Valid  VC (clause 2)
    by omitting a required element.  
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-dtd03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/dtd03.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvdtd06
	"
    Tests  Entity Declared  VC for a parameter entity.  NOTE:  there
    are both VCs and WFCs with this name, which is a specification issue
    in that it is both confusing and in some ways self-contradictory.
    The WFC does not apply to PEs, and even the clause which might
    seem to suggest it could is ruled out in this test.
	 See XML Spec. 1.0 section: 4.1"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-dtd06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/dtd06.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa01
	"
    Tests the Standalone Document Declaration VC, ensuring that
    optional whitespace causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa02
	"
    Tests the Standalone Document Declaration VC, ensuring that
    attributes needing normalization cause a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa02.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa03
	"
    Tests the Standalone Document Declaration VC, ensuring that
    a reference to externally defined entity causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa03.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa04
	"
    Tests the Standalone Document Declaration VC, ensuring that
    attributes needing defaulting cause a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa04.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa05
	"
    Tests the Standalone Document Declaration VC, ensuring that
    a token attribute that needs normalization causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa05.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa06
	"
    Tests the Standalone Document Declaration VC, ensuring that
    a NOTATION attribute that needs normalization
    causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa06.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa07
	"
    Tests the Standalone Document Declaration VC, ensuring that
    an NMTOKEN attribute needing normalization
    causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa07'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa07.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa08
	"
    Tests the Standalone Document Declaration VC, ensuring that
    an NMTOKENS attribute needing normalization
    causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa08'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa08.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa09
	"
    Tests the Standalone Document Declaration VC, ensuring that
    an ID attribute needing normalization causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa09'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa09.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa10
	"
    Tests the Standalone Document Declaration VC, ensuring that
    an IDREF attribute needing normalization causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa10'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa10.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa11
	"
    Tests the Standalone Document Declaration VC, ensuring that
    an IDREFS attribute needing normalization causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa11'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa11.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa12
	"
    Tests the Standalone Document Declaration VC, ensuring that
    an ENTITY attribute needing normalization causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa12'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa12.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa13
	"
    Tests the Standalone Document Declaration VC, ensuring that
    an ENTITIES attribute needing normalization causes a validity error.
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa13'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa13.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvnotsa14
	"
    Tests the Standalone Document Declaration VC, ensuring that
    optional whitespace causes
    a validity error (even if it's CDATA whitespace).
	 See XML Spec. 1.0 section: 2.9"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-not-sa14'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/not-sa14.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvrequired00
	"
    Tests the Required Attribute VC.
	 See XML Spec. 1.0 section: 3.3.2"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-required00'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/required00.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvrequired01
	"
    Tests the Attribute Value Type (declared)
    VC for the xml:space attribute
	 See XML Spec. 1.0 section: 3.1 2.10"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-required01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/required01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsuninvrequired02
	"
    Tests the Attribute Value Type (declared)
    VC for the xml:lang attribute
	 See XML Spec. 1.0 section: 3.1 2.12"

	(self class shouldSkipTests and: [testsToSkip includes: 'inv-required02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/required02.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun error' stamp: ''!
testsunlang01
	"
    Illegal language identification
	 See XML Spec. 1.0 section: 2.11 [33]"

	(self class shouldSkipTests and: [testsToSkip includes: 'lang01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/lang01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun error' stamp: ''!
testsunlang02
	"
    Illegal language identification
	 See XML Spec. 1.0 section: 2.11 [33]"

	(self class shouldSkipTests and: [testsToSkip includes: 'lang02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/lang02.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun error' stamp: ''!
testsunlang03
	"
    Illegal language identification
	 See XML Spec. 1.0 section: 2.11 [33]"

	(self class shouldSkipTests and: [testsToSkip includes: 'lang03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/lang03.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun error' stamp: ''!
testsunlang04
	"
    Illegal language identification
	 See XML Spec. 1.0 section: 2.11 [33]"

	(self class shouldSkipTests and: [testsToSkip includes: 'lang04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/lang04.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun error' stamp: ''!
testsunlang05
	"
    Illegal language identification
	 See XML Spec. 1.0 section: 2.11 [33]"

	(self class shouldSkipTests and: [testsToSkip includes: 'lang05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/lang05.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun error' stamp: ''!
testsunlang06
	"
    Illegal language identification
	 See XML Spec. 1.0 section: 2.11 [33]"

	(self class shouldSkipTests and: [testsToSkip includes: 'lang06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/lang06.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunnotation01
	"
    NOTATION declarations don't need SYSTEM IDs; and
    externally declared notations may be used to declare
    unparsed entities in the internal DTD subset.
    The notation must be reported to the application.
    
	 See XML Spec. 1.0 section: 4.7 [82]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'notation01'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/notation01.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/notation01.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'notation01')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunnotsa01
	"
    A non-standalone document is valid if declared as such.
	 See XML Spec. 1.0 section: 2.9"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'not-sa01'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/not-sa01.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/not-sa01.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'not-sa01')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunnotsa02
	"
    A non-standalone document is valid if declared as such.
	 See XML Spec. 1.0 section: 2.9"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'not-sa02'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/not-sa02.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/not-sa02.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'not-sa02')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunnotsa03
	"
    A non-standalone document is valid if declared as such.
	 See XML Spec. 1.0 section: 2.9"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'not-sa03'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/not-sa03.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/not-sa03.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'not-sa03')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunnotsa04
	"
    A non-standalone document is valid if declared as such. 
	 See XML Spec. 1.0 section: 2.9"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'not-sa04'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/not-sa04.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/not-sa04.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'not-sa04')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunnwfdtd00
	"
    Comma mandatory in content model
	 See XML Spec. 1.0 section: 3.2.1 [55]"

	(self class shouldSkipTests and: [testsToSkip includes: 'nwf-dtd00'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/dtd00.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunnwfdtd01
	"
    Can't mix comma and vertical bar in content models
	 See XML Spec. 1.0 section: 3.2.1 [55]"

	(self class shouldSkipTests and: [testsToSkip includes: 'nwf-dtd01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/dtd01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunoptional
	"
    Tests declarations of  children  content models, and
	the validity constraints associated with them.
	 See XML Spec. 1.0 section: 3 3.2.1 [47]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'optional'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/optional.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/optional.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'optional')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional01
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing no children where
    one is required.
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional02
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    two children where one is required.
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional02.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional03
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where two are required.
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional03.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional04
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    three children where two are required.
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional04.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional05
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or two are
    required (one construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional05.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional06
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or two are
    required (a second construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional06.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional07
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or two are
    required (a third construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional07'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional07.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional08
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or two are
    required (a fourth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional08'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional08.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional09
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or two are
    required (a fifth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional09'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional09.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional10
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    three children where one or two are
    required (a basic construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional10'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional10.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional11
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    three children where one or two are
    required (a second construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional11'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional11.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional12
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    three children where one or two are
    required (a third construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional12'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional12.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional13
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    three children where one or two are
    required (a fourth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional13'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional13.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional14
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    three children where one or two are
    required (a fifth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional14'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional14.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional15
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a basic construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional15'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional15.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional16
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a second construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional16'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional16.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional17
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a third construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional17'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional17.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional18
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a fourth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional18'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional18.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional19
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a fifth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional19'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional19.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional20
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a sixth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional20'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional20.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional21
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a seventh construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional21'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional21.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional22
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (an eigth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional22'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional22.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional23
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a ninth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional23'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional23.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional24
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    no children where one or more are
    required (a tenth construction of that model).
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional24'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional24.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunoptional25
	"
    Tests the Element Valid VC (clause 2) for one
    instance of  children  content model, providing
    text content where one or more elements are
    required.
	 See XML Spec. 1.0 section: 3"

	(self class shouldSkipTests and: [testsToSkip includes: 'optional25'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/optional25.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun error' stamp: ''!
testsunpe01
	"
    Parameter entities must consist of a series of complete markup
    declarations of the types allowed by the nonterminal
    markupdecl, interespersed with whitespace or PERefs.
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'pe01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/pe01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunpi
	"
    No space between PI target name and data
	 See XML Spec. 1.0 section: 2.6 [16]"

	(self class shouldSkipTests and: [testsToSkip includes: 'pi'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/pi.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunpubid01
	"
    Illegal entity ref in public ID
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'pubid01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/pubid01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunpubid02
	"
    Illegal characters in public ID
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'pubid02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/pubid02.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunpubid03
	"
    Illegal characters in public ID
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'pubid03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/pubid03.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunpubid04
	"
    Illegal characters in public ID
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'pubid04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/pubid04.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunpubid05
	"
    SGML-ism:  public ID without system ID
	 See XML Spec. 1.0 section: 2.3 [12]"

	(self class shouldSkipTests and: [testsToSkip includes: 'pubid05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/pubid05.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunrequired00
	"
    Tests the #REQUIRED attribute declaration syntax, and
	the associated validity constraint. 
	 See XML Spec. 1.0 section: 3.3.2 [60]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'required00'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/required00.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/required00.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'required00')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunroot
	"
    Tests the Root Element Type VC
	 See XML Spec. 1.0 section: 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'root'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/root.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunsa01
	"
    A document may be marked 'standalone' if any optional 
	whitespace is defined within the internal DTD subset.
	 See XML Spec. 1.0 section: 2.9 [32]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'sa01'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/sa01.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/sa01.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'sa01')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunsa02
	"
    A document may be marked 'standalone' if any
	attributes that need normalization are
	defined within the internal DTD subset.
	 See XML Spec. 1.0 section: 2.9 [32]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'sa02'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/sa02.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/sa02.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'sa02')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunsa03
	"
    A document may be marked 'standalone' if any
    the defined entities need expanding are internal,
    and no attributes need defaulting or normalization.
    On output, requires notations to be correctly reported.
    
	 See XML Spec. 1.0 section: 2.9 [32]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'sa03'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/sa03.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/sa03.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'sa03')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunsa04
	"
    Like sa03 but relies on attribute
    defaulting defined in the internal subset.
    On output, requires notations to be correctly reported.
    
	 See XML Spec. 1.0 section: 2.9 [32]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'sa04'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/sa04.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/sa04.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'sa04')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunsa05
	"
    Like sa01 but this document is standalone
    since it has no optional whitespace.
    On output, requires notations to be correctly reported.
    
	 See XML Spec. 1.0 section: 2.9 [32]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'sa05'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/sa05.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/sa05.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'sa05')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml01
	"
    SGML-ism: omitted end tag for EMPTY content
	 See XML Spec. 1.0 section: 3 [39]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml01.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml02
	"
    XML declaration must be at the very beginning of a document;
  it s not a processing instruction
	 See XML Spec. 1.0 section: 2.8 "

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml02'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml02.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml03
	"
    Comments may not contain  -- 
	 See XML Spec. 1.0 section: 2.5 [15]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml03'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml03.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml04
	"
    ATTLIST declarations apply to only one element, unlike SGML
	 See XML Spec. 1.0 section: 3.3 [52]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml04'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml04.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml05
	"
    ELEMENT declarations apply to only one element, unlike SGML
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml05'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml05.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml06
	"
    ATTLIST declarations are never global, unlike in SGML
	 See XML Spec. 1.0 section: 3.3 [52]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml06'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml06.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml07
	"
    SGML Tag minimization specifications are not allowed
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml07'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml07.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml08
	"
    SGML Tag minimization specifications are not allowed
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml08'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml08.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml09
	"
    SGML Content model exception specifications are not allowed
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml09'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml09.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml10
	"
    SGML Content model exception specifications are not allowed
	 See XML Spec. 1.0 section: 3.2 [45]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml10'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml10.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml11
	"
    CDATA is not a valid content model spec
	 See XML Spec. 1.0 section: 3.2 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml11'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml11.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml12
	"
    RCDATA is not a valid content model spec
	 See XML Spec. 1.0 section: 3.2 [46]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml12'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml12.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun not wf' stamp: ''!
testsunsgml13
	"
    SGML Unordered content models not allowed
	 See XML Spec. 1.0 section: 3.2.1 [47]"

	(self class shouldSkipTests and: [testsToSkip includes: 'sgml13'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/sgml13.xml' ]
		raises: self exceptionSet2! !

!XMLParserTestsSun methodsFor: 'sun error' stamp: ''!
testsunuri01
	"
    SYSTEM ids may not have URI fragments
	 See XML Spec. 1.0 section: 4.2.2 [75]"

	(self class shouldSkipTests and: [testsToSkip includes: 'uri01'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/not-wf/uri01.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunutf16b
	"
    Tests reading an invalid  big endian  UTF-16 document
	 See XML Spec. 1.0 section: 4.3.3 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'utf16b'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/utf16b.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun invalid' stamp: ''!
testsunutf16l
	"
    Tests reading an invalid  little endian  UTF-16 document
	 See XML Spec. 1.0 section: 4.3.3 2.8"

	(self class shouldSkipTests and: [testsToSkip includes: 'utf16l'])
		ifTrue:[^nil].

	self assert: [self runTest: 'sun/invalid/utf16l.xml']
		raises: self exceptionSet! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvlang01
	"
    Tests a lowercase ISO language code.
	 See XML Spec. 1.0 section: 2.12 [35]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-lang01'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/v-lang01.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/v-lang01.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-lang01')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvlang02
	"
    Tests a ISO language code with a subcode.
	 See XML Spec. 1.0 section: 2.12 [35]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-lang02'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/v-lang02.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/v-lang02.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-lang02')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvlang03
	"
    Tests a IANA language code with a subcode.
	 See XML Spec. 1.0 section: 2.12 [36]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-lang03'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/v-lang03.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/v-lang03.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-lang03')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvlang04
	"
    Tests a user language code with a subcode.
	 See XML Spec. 1.0 section: 2.12 [37]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-lang04'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/v-lang04.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/v-lang04.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-lang04')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvlang05
	"
    Tests an uppercase ISO language code.
	 See XML Spec. 1.0 section: 2.12 [35]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-lang05'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/v-lang05.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/v-lang05.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-lang05')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvlang06
	"
    Tests a user language code.
	 See XML Spec. 1.0 section: 2.12 [37]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-lang06'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/v-lang06.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/v-lang06.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-lang06')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvpe00
	"
    Tests construction of internal entity replacement text, using
    an example in the XML specification.  
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-pe00'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/pe00.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/pe00.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-pe00')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvpe01
	"
    Tests construction of internal entity replacement text, using
    an example in the XML specification.  
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-pe01'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/pe01.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/pe01.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-pe01')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvpe02
	"
    Tests construction of internal entity replacement text, using
    a complex example in the XML specification.  
	 See XML Spec. 1.0 section: 4.5"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-pe02'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/pe02.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/pe02.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-pe02')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !

!XMLParserTestsSun methodsFor: 'sun valid' stamp: ''!
testsunvsgml01
	"
    XML permits token reuse, while SGML does not.
	 See XML Spec. 1.0 section: 3.3.1 [59]"
	|  correctAnswer  result |

	(self class shouldSkipTests and: [testsToSkip includes: 'v-sgml01'])
		ifTrue:[^nil].
	correctAnswer := (self class filenameAt:'sun/valid/out/sgml01.xml')  contentsOfEntireFile.

	[result := self runTest: 'sun/valid/sgml01.xml' ]
		on: self warningSignal
		do: [:warn | warn resume].
	(self class shouldConvertCR: 'v-sgml01')
		ifTrue:[result := result copyReplaceAll: '&#13;' with: '&#10;' ].
	self assert: correctAnswer = result.! !
